CBL NODYNAM,LIB,OBJECT,RENT,RES,APOST
      *                                                               *
      * ------------------------------------------------------------- *
       IDENTIFICATION DIVISION.
      * ------------------------------------------------------------- *
       PROGRAM-ID. READPCF.
      *REMARKS
      *****************************************************************
      *  Module Name      : READPCF                                   *
      *                                                               *
      *  Environment      : z/OS Batch; COBOL II                      *
      *                                                               *
      *  Description      : Test program to print EVENT messages from *
      *                     specified event queue.                    *
      *                                                               *
      *  Limitations      : Tested with the following event types:    *
      *                     Configuration events                      *
      *                     Queue Mgr     events                      *
      *                     Start/stop    events (channel)            *
      *                                                               *
      *                     Based on another program, some            *
      *                     declarations may be unused.               *
      *                                                               *
      *  Function         : This program prints a report showing all  *
      *                     fields of the EVENT messages from a       *
      *                     specified queue and queue manager         *
      *                                                               *
      *  Requires         : WebSphere MQ for z/OS copybooks (5.3.1)   *
      *                                                               *
      * ************************************************************* *
      * ------------------------------------------------------------- *
       ENVIRONMENT DIVISION.
      * ------------------------------------------------------------- *
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
      * ------------------------------------------------------------- *
       DATA DIVISION.
      * ------------------------------------------------------------- *
       FILE SECTION.
      * ------------------------------------------------------------- *
       WORKING-STORAGE SECTION.
      * ------------------------------------------------------------- *
      *
      *    W00 - General work fields
      *
       01  W00-MESSAGE-COUNT           PIC s9(9) BINARY  VALUE ZERO.
       01  W00-DATE.
           05  W00-YY                  PIC 99.
           05  W00-MM                  PIC 99.
           05  W00-DD                  PIC 99.
       01  W00-PRINT-DATA              PIC X(132).
       01  W00-RETURN-CODE             PIC S9(04) BINARY  VALUE ZERO.
      *
      *    W01 - Lines of the print report
      *
       01  W01-HEADER-1.
           05  FILLER                  PIC X(10) VALUE SPACES.
           05  W01-MM                  PIC 99.
           05  FILLER                  PIC X     VALUE '/'.
           05  W01-DD                  PIC 99.
           05  FILLER                  PIC X     VALUE '/'.
           05  W01-YY                  PIC 99.
           05  FILLER                  PIC X(8) VALUE SPACES.
           05  FILLER                  PIC X(20) VALUE
                                                 'EVENT MESSAGE REPORT'.
           05  FILLER                  PIC X(37) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE SPACES.
           05  FILLER                  PIC X(10) VALUE SPACES.
       01  W01-HEADER-2.
           05  FILLER                  PIC X(5) VALUE SPACES.
           05  FILLER                  PIC X(29) VALUE
                                       '        QUEUE MANAGER NAME : '.
           05  W01-MQM-NAME            PIC X(48) VALUE SPACES.
           05  FILLER                  PIC X(30) VALUE SPACES.
       01  W01-HEADER-3.
           05  FILLER                  PIC X(17) VALUE SPACES.
           05  FILLER                  PIC X(17) VALUE
                                                    '    QUEUE NAME : '.
           05  W01-QUEUE-NAME          PIC X(48) VALUE SPACES.
           05  FILLER                  PIC X(30) VALUE SPACES.
       01  W01-HEADER-4.
           05  FILLER                  PIC X(16)  VALUE SPACES.
           05  FILLER                  PIC X(116) VALUE SPACES.
      *
      *    W02 - Data fields derived from the PARM field
      *
       01  W02-MQM                     PIC X(48) VALUE SPACES.
       01  W02-OBJECT                  PIC X(48) VALUE SPACES.
      *
      *    W03 - MQM API fields
      *
       01  W03-BUFFER-LENGTH           PIC S9(9) BINARY  VALUE 4096.
       01  W03-HCONN                   PIC S9(9) BINARY.
       01  W03-OPTIONS                 PIC S9(9) BINARY.
       01  W03-HOBJ                    PIC S9(9) BINARY.
       01  W03-DATA-LENGTH             PIC S9(9) BINARY.
       01  W03-COMPCODE                PIC S9(9) BINARY.
       01  W03-REASON                  PIC S9(9) BINARY.
       01  W03-MESSAGE-DATA            PIC X(4094) VALUE SPACES.
      *
      *    W04 - Error and information messages
      *
       01  W04-MESSAGE-0.
           05  FILLER              PIC X(28) VALUE SPACES.
           05  FILLER              PIC X(35) VALUE
                                  '********** END OF REPORT **********'.
           05  FILLER              PIC X(49) VALUE SPACES.
       01  W04-MESSAGE-1.
           05  FILLER              PIC X(1)  VALUE SPACES.
           05  FILLER              PIC X(122) VALUE
              '********** NO DATA PASSED TO PROGRAM. PROGRAM REQUIRES A
      -       'QUEUE MANAGER NAME AND A QUEUE NAME. **********'.
       01  W04-MESSAGE-2.
           05  FILLER              PIC X(5)  VALUE SPACES.
           05  FILLER              PIC X(107) VALUE
              '********** NO QUEUE MANAGER NAME PASSED TO PROGRAM - DEFA
      -       'ULT USED *****'.
       01  W04-MESSAGE-3.
           05  FILLER              PIC X(18) VALUE SPACES.
           05  FILLER              PIC X(94) VALUE
              '********** NO QUEUE NAME PASSED TO PROGRAM. **********'.
       01  W04-MESSAGE-4.
           05  FILLER              PIC X(1) VALUE SPACES.
           05  FILLER              PIC X(32) VALUE
                   '********** AN ERROR OCCURRED IN '.
           05  W04-MSG4-TYPE       PIC X(10).
           05  FILLER              PIC X(20) VALUE
                   '. COMPLETION CODE = '.
           05  W04-MSG4-COMPCODE   PIC Z(8)9.
           05  FILLER              PIC X(15) VALUE ' REASON CODE ='.
           05  W04-MSG4-REASON     PIC Z(8)9.
           05  FILLER              PIC X(24) VALUE ' **********'.
      *
      *    The following copy files define API control blocks.
      *
       01  W05-MQM-OBJECT-DESCRIPTOR.
           COPY CMQODV.
       01  W05-MQM-MESSAGE-DESCRIPTOR.
           COPY CMQMDV.
       01  W05-MQM-GET-MESSAGE-OPTIONS.
           COPY CMQGMOV.
      *
      *    Copy file of constants (for filling in the control blocks)
      *    and return codes (for testing the result of a call)
      *
       01  W05-MQM-CONSTANTS.
           COPY CMQV.
      *
       01  W05-MQM-CHINIT-CONSTANTS.
           COPY CMQXV.
      *
      *    W06 - Return values
      *
       01  W06-CSQ4-OK             PIC S9(4) VALUE 0.
       01  W06-CSQ4-WARNING        PIC S9(4) VALUE 4.
       01  W06-CSQ4-ERROR          PIC S9(4) VALUE 8.
      *
      * call parameters for program UTIMEDSP
       01  WS-UTIMEDSP.
           05 WS-UTIMEDSP-STCK        PIC X(8).
           05 WS-UTIMEDSP-DISPLAY     PIC X(12).
       01  WS-BLANK9                  PIC X(9) VALUE SPACES.
      *
      * date/time data descriptions
       01  WS-DATE.
           05 WS-DATE-YY              PIC 99.
           05 WS-DATE-MM              PIC 99.
           05 WS-DATE-DD              PIC 99.
       01  WS-TIME.
           05 WS-TIME-HOUR            PIC 99.
           05 WS-TIME-MIN             PIC 99.
           05 WS-TIME-SEC             PIC 99.
           05 WS-TIME-HUND            PIC 99.
       01  WS-TIME1.
           05 WS-TIME1-HOUR           PIC 99.
           05 WS-TIME1-MIN            PIC 99.
           05 WS-TIME1-SEC            PIC 99.
           05 WS-TIME1-HUND           PIC 99.
       01  WS-TIME2.
           05 WS-TIME2-HOUR           PIC 99.
           05 WS-TIME2-MIN            PIC 99.
           05 WS-TIME2-SEC            PIC 99.
           05 WS-TIME2-HUND           PIC 99.
       01  WS-TIME-TOTAL              PIC 9(8).
       01  WS-TIME-TOTAL1             PIC 9(8).
       01  WS-TIME-TOTAL2             PIC 9(8).
       01  WS-DAY-OF-WEEK             PIC 9.
       01  WS-DAY.
           05 WS-DAY-YY               PIC 99.
           05 WS-DAY-DDD              PIC 999.
      * work areas for MQSeries api calls
      *
       01  WS-NAME                    PIC X(48).
       01  WS-HCONN                   PIC S9(9) BINARY.
       01  WS-HOBJ                    PIC S9(9) BINARY.
       01  WS-BUFFLEN                 PIC S9(9) BINARY VALUE ZEROS.
       01  WS-DATALEN                 PIC S9(9) BINARY VALUE ZEROS.
       01  WS-OPTIONS                 PIC S9(9) BINARY.
       01  WS-INTCOUNT                PIC S9(9) BINARY.
       01  WS-SELCOUNT                PIC S9(9) BINARY.
       01  WS-CHARCOUNT               PIC S9(9) BINARY.
       01  WS-CHARLEN                 PIC S9(9) BINARY.
       01  WS-SEL                     PIC S9(9) BINARY.
       01  WS-VERSION                 PIC S9(9) BINARY.
       01  WS-COMPCODE                PIC S9(9) BINARY.
       01  WS-REASON                  PIC S9(9) BINARY.
       01  WS-BUFFER-AREA.
           05 WS-BUFFER-AREA-CHAR     PIC X OCCURS 4194304.
       01  WS-BIN-NUMBERS1.
           05 WS-BIN-NUM1             PIC S9(9) BINARY OCCURS 100.
       01  WS-BIN-NUMBERS2.
           05 WS-BIN-NUM2             PIC S9(9) BINARY OCCURS 100.
      *
      * work areas for MQSeries api calls end
      *
      *
       01  WS-TIME-DISPLAY.
           05 WS-TIME-DISPLAY-HOUR    PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-MIN     PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-SEC     PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-HUND    PIC 99.
      *
       01  WS-TEXT-TITLE              PIC X(30) VALUE SPACES.
       01  WS-TEXT                    PIC X(30) VALUE SPACES.
       01  WS-XTOCHAR-LEN             PIC S9(9) COMP VALUE ZEROS.
       01  WS-LONG-HEXDISP            PIC X(8).
      *
      ******************************************************************
      * Declare a work buffer for processing a sub-structure within the
      * PCF message.
      ******************************************************************
       01  WORK-BUF PIC X(1000).
      * MQCFH substructure
       01  CFH-BUF REDEFINES WORK-BUF.
        02  CFH-HDR.
            COPY CMQCFHL.
      * MQCFIN substructure
       01  CFIN-BUF REDEFINES WORK-BUF.
        02  CFIN-HDR.
            COPY CMQCFINL.
      * MQCFIL substructure
       01  CFIL-BUF REDEFINES WORK-BUF.
        02  CFIL-HDR.
            COPY CMQCFILL.
        02  CFIL-DATA PIC S9(9) BINARY OCCURS 50 TIMES.
      * MQCFST substructure
       01  CFST-BUF REDEFINES WORK-BUF.
        02  CFST-HDR.
            COPY CMQCFSTL.
        02  CFST-DATA PIC X(64).
      * MQCFSL substructure
       01  CFSL-BUF REDEFINES WORK-BUF.
        02  CFSL-HDR.
            COPY CMQCFSLL.
        02  CFSL-DATA PIC X(400).
      * MQCFBS substructure
       01  CFBS-BUF REDEFINES WORK-BUF.
        02  CFBS-HDR.
            COPY CMQCFBSL.
        02  CFBS-DATA PIC X(400).
      *
      ******************************************************************
      * Declare certain variables as both char and num. (PCF processing)
      ******************************************************************
      * Structure length
       01  STRUC-LEN-CHAR.
        02  STRUC-LEN PIC S9(9) BINARY.
            88 WS-START-MESSAGE VALUE 2282.
            88 WS-STOP-MESSAGE  VALUE 2283.
      *
      ******************************************************************
      * Declare other simple variables. (PCF processing)
      ******************************************************************
       01  WS-PCF.
        10  FIRST-BYTE PIC S9(9) BINARY.
        10  PARM-COUNT PIC S9(9) BINARY.
        10  J          PIC S9(9) BINARY.
        10  K          PIC S9(9) BINARY.
        10  L          PIC S9(9) BINARY.
      *
       01  MQ-PCF-CONS.
           COPY CMQCFV.
      *
      *
      *
      * ------------------------------------------------------------- *
       LINKAGE SECTION.
      * ------------------------------------------------------------- *
       01  PARMDATA.
           05  PARM-LEN                PIC S9(03) BINARY.
           05  PARM-STRING             PIC X(100).
      *
           EJECT
      * ------------------------------------------------------------- *
       PROCEDURE DIVISION USING PARMDATA.
      * ------------------------------------------------------------- *
      * ------------------------------------------------------------- *
       A-MAIN SECTION.
      * ------------------------------------------------------------- *
      *
           ACCEPT W00-DATE FROM DATE.
           MOVE W00-MM TO W01-MM.
           MOVE W00-DD TO W01-DD.
           MOVE W00-YY TO W01-YY.
      *
           DISPLAY '================================================'
                   '================================================'.
           DISPLAY W01-HEADER-1.
      *
           PERFORM ACCEPT-TIME.
           DISPLAY '          ' WS-TIME-DISPLAY.
      *
      *    If no data was passed, create a message, print it, and
      *    exit
      *
           IF PARM-LEN = 0 THEN
              DISPLAY W04-MESSAGE-1
              MOVE W06-CSQ4-WARNING TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Separate into the relevant fields any data passed in the
      *    PARM statement
      *
           UNSTRING PARM-STRING DELIMITED BY ALL ','
                                   INTO W02-MQM
                                        W02-OBJECT.
      *
      *    Move the data (spaces if nothing is entered) into the
      *    relevant print fields
      *
           MOVE W02-MQM    TO W01-MQM-NAME.
           MOVE W02-OBJECT TO W01-QUEUE-NAME.
      *
      *    Print a message if the queue manager name is missing, the
      *    default queue manager will be used
      *
           IF W02-MQM = SPACES OR W02-MQM = LOW-VALUES THEN
              DISPLAY W04-MESSAGE-2
           END-IF.
      *
      *    Print a message if the queue name is missing and exit from
      *    program
      *
           IF W02-OBJECT = SPACES OR W02-OBJECT = LOW-VALUES THEN
              DISPLAY W04-MESSAGE-3
              MOVE W06-CSQ4-WARNING TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Print the remaining header lines
      *
           DISPLAY W01-HEADER-2.
           DISPLAY W01-HEADER-3.
           DISPLAY W01-HEADER-4.
      *
      *    Connect to the specified queue manager.
      *
           CALL 'MQCONN' USING W02-MQM
                               W03-HCONN
                               W03-COMPCODE
                               W03-REASON.
      *
      *    Test the output of the connect call.  If the call failed,
      *    print an error message showing the completion code and
      *    reason code
      *
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'CONNECT'     TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Initialize the object descriptor (MQOD) control block.
      *    (The copy file initializes all the other fields)
      *
           MOVE MQOT-Q            TO MQOD-OBJECTTYPE.
           MOVE W02-OBJECT        TO MQOD-OBJECTNAME.
      *
      *    Initialize the working storage fields required to open
      *    the queue
      *
           MOVE MQOO-BROWSE       TO W03-OPTIONS.
      *
      *    Open the queue.
      *
           CALL 'MQOPEN' USING W03-HCONN
                               MQOD
                               W03-OPTIONS
                               W03-HOBJ
                               W03-COMPCODE
                               W03-REASON.
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'OPEN'        TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
              GO TO A-MAIN-DISCONNECT
           END-IF.
      *
      *    Initialize the Get Message Options (MQGMO) control block.
      *    (The copy file initializes all the other fields)
      *
           MOVE MQGMO-NO-WAIT              TO MQGMO-OPTIONS.
           ADD  MQGMO-ACCEPT-TRUNCATED-MSG TO MQGMO-OPTIONS.
           ADD  MQGMO-BROWSE-FIRST         TO MQGMO-OPTIONS.
      *
      *    Make the first get call outside the loop because this call
      *    uses the BROWSE-FIRST option
      *
           CALL 'MQGET' USING W03-HCONN
                              W03-HOBJ
                              MQMD
                              MQGMO
                              W03-BUFFER-LENGTH
                              W03-MESSAGE-DATA
                              W03-DATA-LENGTH
                              W03-COMPCODE
                              W03-REASON.
      *
      *    Test the output of the get call using the PERFORM loop
      *    that follows.
      *
      *    Change the MQGMO Options field to BROWSE-NEXT.
      *
           MOVE MQGMO-NO-WAIT              TO MQGMO-OPTIONS.
           ADD  MQGMO-ACCEPT-TRUNCATED-MSG TO MQGMO-OPTIONS.
           ADD  MQGMO-BROWSE-NEXT          TO MQGMO-OPTIONS.
      *
      *    Loop from here to END-PERFORM until the get call fails
      *
           PERFORM WITH TEST BEFORE
                   UNTIL W03-COMPCODE NOT = MQCC-OK
      *
      *       Increment the relative message number.  Move the message
      *       number and the message data into the print line
      *
              ADD 1                  TO W00-MESSAGE-COUNT
              DISPLAY '*********************************************'
              DISPLAY 'Message number ' W00-MESSAGE-COUNT
      *
      *       Print the message line
      *
              PERFORM DISPLAY-MESSAGE
      *
      *
              MOVE MQMI-NONE TO MQMD-MSGID
              MOVE MQCI-NONE TO MQMD-CORRELID
      *
      *    Clear the message data field before the next get call to
      *    ensure that no old data remains if the next line is shorter
      *
              MOVE SPACES TO W03-MESSAGE-DATA
      *
      *       Get the next message
      *
              CALL 'MQGET' USING W03-HCONN
                                 W03-HOBJ
                                 MQMD
                                 MQGMO
                                 W03-BUFFER-LENGTH
                                 W03-MESSAGE-DATA
                                 W03-DATA-LENGTH
                                 W03-COMPCODE
                                 W03-REASON
      *
      *       Test the output of the MQGET call at the top of the loop.
      *       Exit the loop if an error occurs
      *
           END-PERFORM.
      *
      *
           IF (W03-COMPCODE = MQCC-FAILED)  AND
              (W03-REASON = MQRC-NO-MSG-AVAILABLE) THEN
      *
              DISPLAY W04-MESSAGE-0
      *
           ELSE
              MOVE 'GET'         TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
           END-IF.
      *
       A-MAIN-DISCONNECT.
           CALL 'MQDISC' USING W03-HCONN
                               W03-COMPCODE
                               W03-REASON.
      *
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'DISCONNECT'  TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
           END-IF.
      *
       A-MAIN-END.
      *
      *    Set the return code
      *
           MOVE W00-RETURN-CODE TO RETURN-CODE.
      *
           STOP RUN.
      ******************************************************************
      * This program prepares to analyse the PCF message in COBOL,
      ******************************************************************
       DISPLAY-MESSAGE SECTION.
      *
      * Check msg is a valid PCF reply message
           MOVE W03-MESSAGE-DATA(5:4) TO STRUC-LEN-CHAR
           IF STRUC-LEN NOT = MQCFH-STRUC-LENGTH
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      'MESSAGE IS NOT IN PCF FORMAT'
              DISPLAY WS-TIME-DISPLAY 'Invalid message format bypassed'
              GO TO DISPLAY-MESSAGE-END.
           MOVE W03-MESSAGE-DATA(9:4) TO STRUC-LEN-CHAR
           IF STRUC-LEN NOT = MQCFH-VERSION-1 AND
              STRUC-LEN NOT = MQCFH-VERSION-2
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      'MESSAGE IS NOT IN PCF FORMAT'
              DISPLAY WS-TIME-DISPLAY 'Invalid message format bypassed'
              GO TO DISPLAY-MESSAGE-END.
      *
           MOVE W03-MESSAGE-DATA(29:4) TO STRUC-LEN-CHAR.
           MOVE MQMD-PUTTIME(1:2) TO WS-TIME-DISPLAY-HOUR.
           MOVE MQMD-PUTTIME(3:2) TO WS-TIME-DISPLAY-MIN.
           MOVE MQMD-PUTTIME(5:2) TO WS-TIME-DISPLAY-SEC.
           MOVE MQMD-PUTTIME(7:2) TO WS-TIME-DISPLAY-HUND.
      *
           EVALUATE TRUE                                                
              WHEN WS-START-MESSAGE                                     
                  DISPLAY '  START EVENT '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM START-STOP-EVENT                              
                                                             
              WHEN WS-STOP-MESSAGE                                      
                  DISPLAY '  STOP EVENT  '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM START-STOP-EVENT                              
                                                             
              WHEN OTHER                                                
                  DISPLAY '       EVENT  '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM DISPLAY-EVENT-MESSAGE                         
           END-EVALUATE.                                                           
      *
       DISPLAY-MESSAGE-END.
           EXIT.
      ******************************************************************
      * This program analyses a START/STOP EVENT message
      ******************************************************************
       START-STOP-EVENT SECTION.
      *
      * Initialise index and length for processing loop
           MOVE 1 TO FIRST-BYTE.
           MOVE MQCFH-STRUC-LENGTH   TO STRUC-LEN.
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
           MOVE MQCFH-PARAMETERCOUNT TO PARM-COUNT
      *
           EVALUATE MQCFH-COMPCODE OF MQCFH
               WHEN MQCC-OK
                   MOVE 'MQCC-OK' TO WS-TEXT
               WHEN MQCC-WARNING
                   MOVE 'MQCC-WARNING' TO WS-TEXT
               WHEN MQCC-FAILED
                   MOVE 'MQCC-FAILED' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           DISPLAY '  MQCFH-COMPCODE = ' WS-TEXT.
      *
      * Process each sub-structure in msg
           PERFORM TEST BEFORE VARYING J FROM 1 BY 1
             UNTIL (J > PARM-COUNT)
      * Compute index of start of next sub-structure
           COMPUTE FIRST-BYTE = FIRST-BYTE + STRUC-LEN
      * Compute start of length field (offset 4 from start of structure)
           COMPUTE K = FIRST-BYTE + 4
      * Get length of sub-structure
           MOVE W03-MESSAGE-DATA(K:4) TO STRUC-LEN-CHAR
      * Copy sub-structure into work buffer
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
      * Process sub-structure according to type
           IF MQCFIN-TYPE = MQCFT-INTEGER THEN
              PERFORM DISPLAY-SSTOP-INTEGER-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-INTEGER-LIST THEN
              PERFORM DISPLAY-INTEGER-LIST-STRUC
           ELSE IF MQCFST-TYPE = MQCFT-STRING THEN
              PERFORM DISPLAY-SSTOP-STRING-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-STRING-LIST THEN
              PERFORM DISPLAY-STRING-LIST-STRUC
           ELSE
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      '** MESSAGE IS NO LONGER IN PCF FORMAT **'
              GO TO START-STOP-EVENT-END
           END-IF END-IF END-IF END-IF
      * End of loop
           END-PERFORM.
      *
       START-STOP-EVENT-END.
           EXIT.
      ******************************************************************
      * This program analyses a PCF / EVENT message in COBOL,
      ******************************************************************
       DISPLAY-EVENT-MESSAGE SECTION.
      *
      * Initialise index and length for processing loop
           MOVE 1 TO FIRST-BYTE.
           MOVE MQCFH-STRUC-LENGTH   TO STRUC-LEN.
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
           MOVE MQCFH-PARAMETERCOUNT TO PARM-COUNT
      *
           PERFORM DISPLAY-HEADER-STRUC.
      *
      * Process each sub-structure in msg
           PERFORM TEST BEFORE VARYING J FROM 1 BY 1
             UNTIL (J > PARM-COUNT)
      * Compute index of start of next sub-structure
           COMPUTE FIRST-BYTE = FIRST-BYTE + STRUC-LEN
      * Compute start of length field (offset 4 from start of structure)
           COMPUTE K = FIRST-BYTE + 4
      * Get length of sub-structure
           MOVE W03-MESSAGE-DATA(K:4) TO STRUC-LEN-CHAR
      * Copy sub-structure into work buffer
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
      * Process sub-structure according to type
           IF MQCFIN-TYPE = MQCFT-INTEGER THEN
              PERFORM DISPLAY-INTEGER-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-INTEGER-LIST THEN
              PERFORM DISPLAY-INTEGER-LIST-STRUC
           ELSE IF MQCFST-TYPE = MQCFT-STRING THEN
              PERFORM DISPLAY-STRING-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-STRING-LIST THEN
              PERFORM DISPLAY-STRING-LIST-STRUC
           ELSE IF MQCFBS-TYPE = MQCFT-BYTE-STRING THEN
              PERFORM DISPLAY-BYTE-STRING
           ELSE
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      '** MESSAGE IS NO LONGER IN PCF FORMAT **'
              GO TO DISPLAY-EVENT-MESSAGE-END
           END-IF END-IF END-IF END-IF END-IF
      * End of loop
           END-PERFORM.
      *
       DISPLAY-EVENT-MESSAGE-END.
           EXIT.
      ******************************************************************
      * Process header structure.
      ******************************************************************
       DISPLAY-HEADER-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH structure'.
      *
           EVALUATE MQCFH-TYPE OF MQCFH
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-TYPE OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-TYPE             ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-TYPE OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-STRUCLENGTH OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-STRUCLENGTH      ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-STRUCLENGTH OF MQCFH.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-VERSION OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-VERSION          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-VERSION OF MQCFH.
      *
           EVALUATE MQCFH-COMMAND OF MQCFH
               WHEN MQCMD-Q-MGR-EVENT
                   MOVE 'QMGR EVENT' TO WS-TEXT
               WHEN MQCMD-PERFM-EVENT
                   MOVE 'PERFORMANCE EVENT' TO WS-TEXT
               WHEN MQCMD-CHANNEL-EVENT
                   MOVE 'CHANNEL EVENT' TO WS-TEXT
               WHEN MQCMD-CONFIG-EVENT
                   MOVE 'CONFIG EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '***OTHER***' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-COMMAND OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-COMMAND          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-COMMAND OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-MSGSEQNUMBER OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-MSGSEQNUMBER     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-MSGSEQNUMBER OF MQCFH.
      *
           EVALUATE MQCFH-CONTROL OF MQCFH
               WHEN MQCFC-LAST
                   MOVE 'LAST MESSAGE' TO WS-TEXT
               WHEN MQCFC-NOT-LAST
                   MOVE 'NOT LAST MESSAGE' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-CONTROL OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-CONTROL          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-CONTROL OF MQCFH
                   ' ' WS-TEXT.
      *
           EVALUATE MQCFH-COMPCODE OF MQCFH
               WHEN MQCC-OK
                   MOVE 'MQCC-OK' TO WS-TEXT
               WHEN MQCC-WARNING
                   MOVE 'MQCC-WARNING' TO WS-TEXT
               WHEN MQCC-FAILED
                   MOVE 'MQCC-FAILED' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-COMPCODE OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-COMPCODE         ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-COMPCODE OF MQCFH
                   ' ' WS-TEXT.
      *
           EVALUATE MQCFH-REASON OF MQCFH
               WHEN MQRC-GET-INHIBITED
                   MOVE 'GET INHIBITED' TO WS-TEXT
               WHEN MQRC-PUT-INHIBITED
                   MOVE 'PUT INHIBITED' TO WS-TEXT
               WHEN MQRC-ALIAS-BASE-Q-TYPE-ERROR
                   MOVE 'ALIAS BASE Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-ALIAS-BASE-Q
                   MOVE 'UNKNOWN ALIAS BASE Q' TO WS-TEXT
               WHEN MQRC-UNKNOWN-OBJECT-NAME
                   MOVE 'UNKNOWN OBJECT NAME' TO WS-TEXT
               WHEN MQRC-DEF-XMIT-Q-TYPE-ERROR
                   MOVE 'DEF XMIT Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-DEF-XMIT-Q-USAGE-ERROR
                   MOVE 'DEF XMIT Q USAGE ERROR' TO WS-TEXT
               WHEN MQRC-Q-TYPE-ERROR
                   MOVE 'Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-REMOTE-Q-NAME-ERROR
                   MOVE 'REMOTE Q NAME ERROR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-DEF-XMIT-Q
                   MOVE 'UNKNOWN DEF XMIT Q' TO WS-TEXT
               WHEN MQRC-UNKNOWN-REMOTE-Q-MGR
                   MOVE 'UNKNOWN REMOTE Q MGR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-XMIT-Q
                   MOVE 'UNKNOWN XMIT Q' TO WS-TEXT
               WHEN MQRC-XMIT-Q-TYPE-ERROR
                   MOVE 'XMIT Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-XMIT-Q-USAGE-ERROR
                   MOVE 'XMIT Q USAGE ERROR' TO WS-TEXT
               WHEN MQRC-CHANNEL-STARTED
                   MOVE 'CHANNEL STARTED' TO WS-TEXT
               WHEN MQRC-CHANNEL-STOPPED
                   MOVE 'CHANNEL STOPPED' TO WS-TEXT
               WHEN MQRC-CONFIG-CREATE-OBJECT
                   MOVE 'CREATE OBJECT' TO WS-TEXT
               WHEN MQRC-CONFIG-CHANGE-OBJECT
                   MOVE 'CHANGE OBJECT' TO WS-TEXT
               WHEN MQRC-CONFIG-DELETE-OBJECT
                   MOVE 'DELETE OBJECT' TO WS-TEXT
               WHEN MQRC-CONFIG-REFRESH-OBJECT
                   MOVE 'REFRESH OBJECT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-REASON OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-REASON           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-REASON OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-PARAMETERCOUNT OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-PARAMETERCOUNT   ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-PARAMETERCOUNT OF MQCFH.
       DISPLAY-HEADER-STRUC-END.
           EXIT.
      ******************************************************************
      * Process integer structure.
      ******************************************************************
       DISPLAY-INTEGER-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN structure'.
      *
           EVALUATE MQCFIN-TYPE OF MQCFIN
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-TYPE OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-TYPE OF MQCFIN
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-STRUCLENGTH OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-STRUCLENGTH OF MQCFIN.
      *
      * parameter
      *
           PERFORM  MQCFIN-PARAMETER-LITERAL.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-PARAMETER OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-PARAMETER OF MQCFIN
                   ' ' WS-TEXT.
      *
      * value
      *
           PERFORM  MQCFIN-VALUE-LITERAL.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-VALUE OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-VALUE           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-VALUE OF MQCFIN
                   ' ' WS-TEXT.
      *
       DISPLAY-INTEGER-STRUC-END.
           EXIT.
      ******************************************************************
      * Process integer START/STOP structure.
      ******************************************************************
       DISPLAY-SSTOP-INTEGER-STRUC SECTION.
      *
      * parameter
      *
           MOVE SPACES TO WS-TEXT-TITLE.
           EVALUATE MQCFIN-PARAMETER OF MQCFIN
               WHEN MQIACF-ERROR-IDENTIFIER
                   MOVE 'MQIACF-ERROR-IDENTIFIER' TO WS-TEXT-TITLE
               WHEN MQIACF-REASON-QUALIFIER
                   MOVE 'MQIACF-REASON-QUALIFIER' TO WS-TEXT-TITLE
               WHEN MQIACF-AUX-ERROR-DATA-INT-1
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-1' TO WS-TEXT-TITLE
               WHEN MQIACF-AUX-ERROR-DATA-INT-2
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-2' TO WS-TEXT-TITLE
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT-TITLE
           END-EVALUATE.
      *
      * value
      *
           MOVE SPACES TO WS-TEXT.
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-REASON-QUALIFIER
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQRQ-CHANNEL-STOPPED-OK
                      MOVE 'MQRQ-CHANNEL-STOPPED-OK' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-ERROR
                      MOVE 'MQRQ-CHANNEL-STOPPED-ERROR' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-RETRY
                      MOVE 'MQRQ-CHANNEL-STOPPED-RETRY' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-DISABLED
                      MOVE 'MQRQ-CHANNEL-STOPPED-DISABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-VALUE OF MQCFIN
                                WS-LONG-HEXDISP.
      *
           DISPLAY '    ' WS-TEXT-TITLE ' '
                   'X''' WS-LONG-HEXDISP   ''''
      *            ' ' MQCFIN-VALUE OF MQCFIN
                   ' ' WS-TEXT.
      *
       DISPLAY-SSTOP-INTEGER-STRUC-ND.
           EXIT.
      ******************************************************************
      * Process integer-list structure.
      ******************************************************************
       DISPLAY-INTEGER-LIST-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL structure'.
      *
           EVALUATE MQCFIL-TYPE OF MQCFIL
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-TYPE OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-TYPE OF MQCFIL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-STRUCLENGTH OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-STRUCLENGTH OF MQCFIL.
      *
      * parameter
           EVALUATE MQCFIL-PARAMETER OF MQCFIL
               WHEN MQIACH-CHANNEL-ERROR-DATA
                   MOVE 'MQIACH-CHANNEL-ERROR-DATA' TO WS-TEXT
               WHEN OTHER
                   MOVE '*NOT CODED*' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-PARAMETER OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-PARAMETER OF MQCFIL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-COUNT OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-COUNT           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-COUNT OF MQCFIL.
      *
           PERFORM TEST BEFORE VARYING L FROM 1 BY 1
             UNTIL (L > MQCFIL-COUNT)
             DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'Value                  =' CFIL-DATA(L)
           END-PERFORM.
       DISPLAY-INTEGER-LIST-STRUC-END.
           EXIT.
      ******************************************************************
      * Process string structure.
      ******************************************************************
       DISPLAY-STRING-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST structure'.
      *
           EVALUATE MQCFST-TYPE OF MQCFST
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-TYPE OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-TYPE OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-STRUCLENGTH OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-STRUCLENGTH OF MQCFST.
      *
      * parameter
      *
           PERFORM  MQCFST-PARAMETER-LITERAL.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-PARAMETER OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-PARAMETER OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-CODEDCHARSETID OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-CODEDCHARSETID  ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-CODEDCHARSETID OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-STRINGLENGTH OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-STRINGLENGTH OF MQCFST
                   ' ' WS-TEXT.
      *
      * value
      *
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'String=' CFST-DATA(1:MQCFST-STRINGLENGTH) '='.
       DISPLAY-STRING-STRUC-END.
           EXIT.
      ******************************************************************
      * Process START/STOP string structure.
      ******************************************************************
       DISPLAY-SSTOP-STRING-STRUC SECTION.
      * parameter
           EVALUATE MQCFST-PARAMETER OF MQCFST
               WHEN MQCACF-APPL-NAME
                   MOVE 'MQCACF-APPL-NAME' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-1
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-1' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-2
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-2' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-3
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-3' TO WS-TEXT
               WHEN MQCA-BASE-Q-NAME
                   MOVE 'MQCA-BASE-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CHANNEL-NAME
                   MOVE 'MQCACH-CHANNEL-NAME' TO WS-TEXT
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCACF-OBJECT-Q-MGR-NAME
                   MOVE 'MQCACF-OBJECT-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-NAME
                   MOVE 'MQCA-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-MGR-NAME
                   MOVE 'MQCA-REMOTE-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-XMIT-Q-NAME
                   MOVE 'MQCA-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-XMIT-Q-NAME
                   MOVE 'MQCACH-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CONNECTION-NAME
                   MOVE 'MQCACH-CONNECTION-NAME' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
      *
           DISPLAY  '    ' WS-TEXT
                   ' =' CFST-DATA(1:MQCFST-STRINGLENGTH) '='.
      *
       DISPLAY-SSTOP-STRING-STRUC-END.
           EXIT.
      ******************************************************************
      * Process string-list structure.
      ******************************************************************
       DISPLAY-STRING-LIST-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL structure'.
      *
           EVALUATE MQCFSL-TYPE OF MQCFSL
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-TYPE OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-TYPE OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-STRUCLENGTH OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-STRUCLENGTH OF MQCFSL.
      *
      * parameter
      *
           PERFORM  MQCFSL-PARAMETER-LITERAL.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-PARAMETER OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-PARAMETER OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-CODEDCHARSETID OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-CODEDCHARSETID  ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-CODEDCHARSETID OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-STRINGLENGTH OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-STRINGLENGTH OF MQCFSL
                   ' ' WS-TEXT.
      *
           PERFORM TEST BEFORE VARYING L FROM 1 BY 1
             UNTIL (L > MQCFSL-COUNT)
             COMPUTE K = (L - 1) * MQCFSL-STRINGLENGTH + 1
             DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                     'String=' CFSL-DATA(K:MQCFSL-STRINGLENGTH) '='
           END-PERFORM.
      *
       DISPLAY-STRING-LIST-STRUC-END.
           EXIT.
      ******************************************************************
      * Process byte string structure.
      ******************************************************************
       DISPLAY-BYTE-STRING SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS structure'.
      *
           EVALUATE MQCFBS-TYPE OF MQCFBS
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-BYTE-STRING
                   MOVE 'BYTE STRING' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-TYPE OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-TYPE OF MQCFBS
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-STRUCLENGTH OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-STRUCLENGTH OF MQCFBS.
      *
      * parameter
           EVALUATE MQCFBS-PARAMETER OF MQCFBS
               WHEN MQBACF-EVENT-ACCOUNTING-TOKEN
                   MOVE 'MQBACF-EVENT-ACCOUNTING-TOKEN' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-PARAMETER OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-PARAMETER OF MQCFBS
                   ' ' WS-TEXT.

           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-STRINGLENGTH OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-STRINGLENGTH OF MQCFBS
                   ' ' WS-TEXT.

           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'String=' CFBS-DATA(1:MQCFBS-STRINGLENGTH) '='.

      *    END-PERFORM.
       DISPLAY-STRING-LIST-STRUC-END.
           EXIT.
      *
       ACCEPT-TIME SECTION.
           ACCEPT WS-TIME FROM TIME.
           MOVE WS-TIME-HOUR TO WS-TIME-DISPLAY-HOUR.
           MOVE WS-TIME-MIN  TO WS-TIME-DISPLAY-MIN.
           MOVE WS-TIME-SEC  TO WS-TIME-DISPLAY-SEC.
           MOVE WS-TIME-HUND TO WS-TIME-DISPLAY-HUND.
       ACCEPT-TIME-END.
           EXIT.
      *
       MQCFST-PARAMETER-LITERAL SECTION.
      ******************************************************************
      * Set up the Parameter description for MQCFST
      ******************************************************************
      *
      * Starting General Attributes
      *
           MOVE SPACES TO WS-TEXT.
      *
           EVALUATE MQCFST-PARAMETER OF MQCFST
               WHEN MQCACF-APPL-NAME
                   MOVE 'MQCACF-APPL-NAME' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-1
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-1' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-2
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-2' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-3
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-3' TO WS-TEXT
               WHEN MQCA-BASE-Q-NAME
                   MOVE 'MQCA-BASE-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CHANNEL-NAME
                   MOVE 'MQCACH-CHANNEL-NAME' TO WS-TEXT
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCACF-OBJECT-Q-MGR-NAME
                   MOVE 'MQCACF-OBJECT-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-NAME
                   MOVE 'MQCA-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-MGR-NAME
                   MOVE 'MQCA-REMOTE-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-XMIT-Q-NAME
                   MOVE 'MQCA-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-XMIT-Q-NAME
                   MOVE 'MQCACH-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CONNECTION-NAME
                   MOVE 'MQCACH-CONNECTION-NAME' TO WS-TEXT
               WHEN MQCACF-EVENT-USER-ID
                   MOVE 'MQCACF-EVENT-USER-ID' TO WS-TEXT
               WHEN MQCACF-EVENT-Q-MGR
                   MOVE 'MQCACH-EVENT-Q-MGR' TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-IDENTITY
                   MOVE 'MQCACH-EVENT-APPL-IDENTITY' TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-NAME
                   MOVE 'MQCACH-EVENT-APPL-NAME' TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-ORIGIN
                   MOVE 'MQCACH-EVENT-APPL-ORIGIN' TO WS-TEXT
               WHEN MQCA-NAMELIST-NAME
                   MOVE 'MQCA-NAMELIST-NAME' TO WS-TEXT
               WHEN MQCA-STORAGE-CLASS
                   MOVE 'MQCA-STORAGE-CLASS' TO WS-TEXT
               WHEN MQCA-AUTH-INFO-NAME
                   MOVE 'AUTH-INFO-NAME' TO WS-TEXT
               WHEN MQCA-CF-STRUC-NAME
                   MOVE 'CF-STRUC-NAME' TO WS-TEXT
      *
      * Starting Authentication Information Attributes
      *
               WHEN MQCA-AUTH-INFO-DESC
                   MOVE 'MQCA-AUTH-INFO-DESC' TO WS-TEXT
               WHEN MQCA-AUTH-INFO-CONN-NAME
                   MOVE 'MQCA-AUTH-INFO-CONN-NAME' TO WS-TEXT
               WHEN MQCA-LDAP-USER-NAME
                   MOVE 'MQCA-LDAP-USER-NAME' TO WS-TEXT
               WHEN MQCA-LDAP-PASSWORD
                   MOVE 'MQCA-LDAP-PASSWORD' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
      *
      * Starting CF Structure Attributes
      *
               WHEN MQCA-CF-STRUC-DESC
                   MOVE 'MQCA-CF-STRUC-DESC' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
      *
      * Starting Channel Attributes
      *
               WHEN MQCACH-CHANNEL-NAME
                   MOVE 'MQCACH-CHANNEL-NAME' TO WS-TEXT
               WHEN MQCACH-MODE-NAME
                   MOVE 'MQCACH-MODE-NAME' TO WS-TEXT
               WHEN MQCACH-TP-NAME
                   MOVE 'MQCACH-TP-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCACH-XMIT-Q-NAME
                   MOVE 'MQCACH-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CONNECTION-NAME
                   MOVE 'MQCACH-CONNECTION-NAME' TO WS-TEXT
               WHEN MQCACH-MCA-NAME
                   MOVE 'MQCACH-MCA-NAME' TO WS-TEXT
               WHEN MQCACH-DESC
                   MOVE 'MQCACH-DESC' TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-NAME
                   MOVE 'MQCACH-SEC-EXIT-NAME' TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-USER-DATA
                   MOVE 'MQCACH-SEC-EXIT-USER-DATA' TO WS-TEXT
               WHEN MQCACH-MCA-USER-ID
                   MOVE 'MQCACH-MCA-USER-ID' TO WS-TEXT
               WHEN MQCACH-USER-ID
                   MOVE 'MQCACH-USER-ID' TO WS-TEXT
               WHEN MQCACH-PASSWORD
                   MOVE 'MQCACH-PASSWORD' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
               WHEN MQCA-CLUSTER-NAME
                   MOVE 'MQCA-CLUSTER-NAME' TO WS-TEXT
               WHEN MQCACH-LOCAL-ADDRESS
                   MOVE 'MQCACH-LOCAL-ADDRESS' TO WS-TEXT
               WHEN MQCACH-SSL-CIPHER-SPEC
                   MOVE 'MQCACH-SSL-CIPHER-SPEC' TO WS-TEXT
               WHEN MQCACH-SSL-PEER-NAME
                   MOVE 'MQCACH-SSL-PEER-NAME' TO WS-TEXT
      *
      * Starting Namelist Attributes
      *
               WHEN MQCA-NAMELIST-NAME
                   MOVE 'MQCA-NAMELIST-NAME' TO WS-TEXT
               WHEN MQCA-NAMELIST-DESC
                   MOVE 'MQCA-NAMELIST-DESC' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
      *
      * Starting Process Attributes
      *
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCA-PROCESS-DESC
                   MOVE 'MQCA-PROCESS-DESC' TO WS-TEXT
               WHEN MQCA-APPL-ID
                   MOVE 'MQCA-APPL-ID' TO WS-TEXT
               WHEN MQCA-ENV-DATA
                   MOVE 'MQCA-ENV-DATA' TO WS-TEXT
               WHEN MQCA-USER-DATA
                   MOVE 'MQCA-USER-DATA' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
      *
      * Starting Queue Attributes
      *
               WHEN MQCA-Q-NAME
                   MOVE 'MQCA-Q-NAME' TO WS-TEXT
               WHEN MQCA-Q-DESC
                   MOVE 'MQCA-Q-DESC' TO WS-TEXT
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCA-BACKOUT-REQ-Q-NAME
                   MOVE 'MQCA-BACKOUT-REQ-Q-NAME' TO WS-TEXT
               WHEN MQCA-CREATION-DATE
                   MOVE 'MQCA-CREATION-DATE' TO WS-TEXT
               WHEN MQCA-CREATION-TIME
                   MOVE 'MQCA-CREATION-TIME' TO WS-TEXT
               WHEN MQCA-INITIATION-Q-NAME
                   MOVE 'MQCA-INITIATION-Q-NAME' TO WS-TEXT
               WHEN MQCA-TRIGGER-DATA
                   MOVE 'MQCA-TRIGGER-DATA' TO WS-TEXT
               WHEN MQCA-BASE-Q-NAME
                   MOVE 'MQCA-BASE-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-NAME
                   MOVE 'MQCA-REMOTE-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-MGR-NAME
                   MOVE 'MQCA-REMOTE-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-XMIT-Q-NAME
                   MOVE 'MQCA-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
               WHEN MQCA-CLUSTER-NAME
                   MOVE 'MQCA-CLUSTER-NAME' TO WS-TEXT
               WHEN MQCA-CLUSTER-NAMELIST
                   MOVE 'MQCA-CLUSTER-NAMELIST' TO WS-TEXT
               WHEN MQCA-STORAGE-CLASS
                   MOVE 'MQCA-STORAGE-CLASS' TO WS-TEXT
               WHEN MQCA-CF-STRUC-NAME
                   MOVE 'MQCA-CF-STRUC-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-DESC
                   MOVE 'MQCA-Q-MGR-DESC' TO WS-TEXT
               WHEN MQCA-IGQ-USER-ID
                   MOVE 'MQCA-IGQ-USER-ID' TO WS-TEXT
               WHEN MQCA-SSL-KEY-REPOSITORY
                   MOVE 'MQCA-SSL-KEY-REPOSITORY' TO WS-TEXT
               WHEN MQCA-SSL-CRL-NAMELIST
                   MOVE 'MQCA-SSL-CRL-NAMELIST' TO WS-TEXT
               WHEN MQCA-QSG-NAME
                   MOVE 'MQCA-QSG-NAME' TO WS-TEXT
               WHEN MQCA-DEAD-LETTER-Q-NAME
                   MOVE 'MQCA-DEAD-LETTER-Q-NAME' TO WS-TEXT
               WHEN MQCA-COMMAND-INPUT-Q-NAME
                   MOVE 'MQCA-COMMAND-INPUT-Q-NAME' TO WS-TEXT
               WHEN MQCA-DEF-XMIT-Q-NAME
                   MOVE 'MQCA-DEF-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCA-CHANNEL-AUTO-DEF-EXIT
                   MOVE 'MQCA-CHANNEL-AUTO-DEF-EXIT' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
               WHEN MQCA-CLUSTER-WORKLOAD-EXIT
                   MOVE 'MQCA-CLUSTER-WORKLOAD-EXIT' TO WS-TEXT
               WHEN MQCA-CLUSTER-WORKLOAD-DATA
                   MOVE 'MQCA-CLUSTER-WORKLOAD-DATA' TO WS-TEXT
               WHEN MQCA-Q-MGR-IDENTIFIER
                   MOVE 'MQCA-Q-MGR-IDENTIFIER' TO WS-TEXT
               WHEN MQCA-REPOSITORY-NAME
                   MOVE 'MQCA-REPOSITORY-NAME' TO WS-TEXT
               WHEN MQCA-REPOSITORY-NAMELIST
                   MOVE 'MQCA-REPOSITORY-NAMELIST' TO WS-TEXT
      *
      * Starting Storage Class Attributes
      *
               WHEN MQCA-STORAGE-CLASS-DESC
                   MOVE 'MQCA-STORAGE-CLASS-DESC' TO WS-TEXT
               WHEN MQCA-XCF-GROUP-NAME
                   MOVE 'MQCA-XCF-GROUP-NAME' TO WS-TEXT
               WHEN MQCA-XCF-MEMBER-NAME
                   MOVE 'MQCA-XCF-MEMBER-NAME' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
      *
      * Default
      *
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
      *
       MQCFST-PARAMETER-LITERAL-END.
           EXIT.
      *
       MQCFIN-PARAMETER-LITERAL SECTION.
      ******************************************************************
      * Set up the Parameter description for MQCFIN
      ******************************************************************
      *
      * Starting General Attributes
      *
           MOVE SPACES TO WS-TEXT.
      *
           EVALUATE MQCFIN-PARAMETER OF MQCFIN
               WHEN MQIA-APPL-TYPE
                   MOVE 'MQIA-APPL-TYPE' TO WS-TEXT
               WHEN MQIA-Q-TYPE
                   MOVE 'MQIA-Q-TYPE' TO WS-TEXT
               WHEN MQIA-TIME-SINCE-RESET
                   MOVE 'MQIA-TIME-SINCE-RESET' TO WS-TEXT
               WHEN MQIA-HIGH-Q-DEPTH
                   MOVE 'MQIA-HIGH-Q-DEPTH' TO WS-TEXT
               WHEN MQIA-MSG-DEQ-COUNT
                   MOVE 'MQIA-MSG-DEQ-COUNT     ' TO WS-TEXT
               WHEN MQIA-MSG-ENQ-COUNT
                   MOVE 'MQIA-MSG-ENQ-COUNT     ' TO WS-TEXT
               WHEN MQIACF-ERROR-IDENTIFIER
                   MOVE 'MQIACF-ERROR-IDENTIFIER' TO WS-TEXT
               WHEN MQIACF-REASON-QUALIFIER
                   MOVE 'MQIACF-REASON-QUALIFIER' TO WS-TEXT
               WHEN MQIACF-AUX-ERROR-DATA-INT-1
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-1' TO WS-TEXT
               WHEN MQIACF-AUX-ERROR-DATA-INT-2
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-2' TO WS-TEXT
               WHEN MQIACF-EVENT-ORIGIN
                   MOVE 'MQIACF-EVENT-ORIGIN' TO WS-TEXT
               WHEN MQIACF-EVENT-APPL-TYPE
                   MOVE 'MQIACF-EVENT-APPL-TYPE' TO WS-TEXT
               WHEN MQIACF-OBJECT-TYPE
                   MOVE 'MQIACF-OBJECT-TYPE' TO WS-TEXT
               WHEN MQIA-QSG-DISP
                   MOVE 'MQIA-QSG-DISP' TO WS-TEXT
      *
      * Starting Authentication Information Attributes
      *
               WHEN MQIA-AUTH-INFO-TYPE
                   MOVE 'MQIA-AUTH-INFO-TYPE' TO WS-TEXT
      *
      * Starting CF Structure Attributes
      *
               WHEN MQIA-CF-LEVEL
                   MOVE 'MQIA-CF-LEVEL' TO WS-TEXT
               WHEN MQIA-CF-RECOVER
                   MOVE 'MQIA-CF-RECOVER' TO WS-TEXT
      *
      * Starting Channel Attributes
      *
               WHEN MQIACH-CHANNEL-TYPE
                   MOVE 'MQIACH-CHANNEL-TYPE' TO WS-TEXT
               WHEN MQIACH-XMIT-PROTOCOL-TYPE
                   MOVE 'MQIACH-XMIT-PROTOCOL-TYPE' TO WS-TEXT
               WHEN MQIACH-BATCH-SIZE
                   MOVE 'MQIACH-BATCH-SIZE' TO WS-TEXT
               WHEN MQIACH-DISC-INTERVAL
                   MOVE 'MQIACH-DISC-INTERVAL' TO WS-TEXT
               WHEN MQIACH-SHORT-RETRY
                   MOVE 'MQIACH-SHORT-RETRY' TO WS-TEXT
               WHEN MQIACH-SHORT-TIMER
                   MOVE 'MQIACH-SHORT-TIMER' TO WS-TEXT
               WHEN MQIACH-LONG-RETRY
                   MOVE 'MQIACH-LONG-RETRY' TO WS-TEXT
               WHEN MQIACH-LONG-TIMER
                   MOVE 'MQIACH-LONG-TIMER' TO WS-TEXT
               WHEN MQIACH-DATA-CONVERSION
                   MOVE 'MQIACH-DATA-CONVERSION' TO WS-TEXT
               WHEN MQIACH-PUT-AUTHORITY
                   MOVE 'MQIACH-PUT-AUTHORITY' TO WS-TEXT
               WHEN MQIACH-SEQUENCE-NUMBER-WRAP
                   MOVE 'MQIACH-SEQUENCE-NUMBER-WRAP' TO WS-TEXT
               WHEN MQIACH-MAX-MSG-LENGTH
                   MOVE 'MQIACH-MAX-MSG-LENGTH' TO WS-TEXT
               WHEN MQIACH-MCA-TYPE
                   MOVE 'MQIACH-MCA-TYPE' TO WS-TEXT
               WHEN MQIACH-BATCH-INTERVAL
                   MOVE 'MQIACH-BATCH-INTERVAL' TO WS-TEXT
               WHEN MQIACH-HB-INTERVAL
                   MOVE 'MQIACH-HB-INTERVAL' TO WS-TEXT
               WHEN MQIACH-NPM-SPEED
                   MOVE 'MQIACH-NPM-SPEED' TO WS-TEXT
               WHEN MQIACH-NETWORK-PRIORITY
                   MOVE 'MQIACH-NETWORK-PRIORITY' TO WS-TEXT
               WHEN MQIACH-BATCH-HB
                   MOVE 'MQIACH-BATCH-HB' TO WS-TEXT
               WHEN MQIACH-KEEP-ALIVE-INTERVAL
                   MOVE 'MQIACH-KEEP-ALIVE-INTERVAL' TO WS-TEXT
               WHEN MQIACH-SSL-CLIENT-AUTH
                   MOVE 'MQIACH-SSL-CLIENT-AUTH' TO WS-TEXT
      *
      * Starting Namelist Attributes
      *
               WHEN MQIA-NAMELIST-TYPE
                   MOVE 'MQIA-NAMELIST-TYPE' TO WS-TEXT
               WHEN MQIA-NAME-COUNT
                   MOVE 'MQIA-NAME-COUNT' TO WS-TEXT
      *
      * Starting Process Attributes
      *
               WHEN MQIA-APPL-TYPE
                   MOVE 'MQIA-APPL-TYPE' TO WS-TEXT
      *
      * Starting Queue Attributes
      *
               WHEN MQIA-Q-TYPE
                   MOVE 'MQIA-Q-TYPE' TO WS-TEXT
               WHEN MQIA-INHIBIT-GET
                   MOVE 'MQIA-INHIBIT-GET' TO WS-TEXT
               WHEN MQIA-INHIBIT-PUT
                   MOVE 'MQIA-INHIBIT-PUT' TO WS-TEXT
               WHEN MQIA-DEF-PRIORITY
                   MOVE 'MQIA-DEF-PRIORITY' TO WS-TEXT
               WHEN MQIA-DEF-PERSISTENCE
                   MOVE 'MQIA-DEF-PERSISTENCE' TO WS-TEXT
               WHEN MQIA-MAX-Q-DEPTH
                   MOVE 'MQIA-MAX-Q-DEPTH' TO WS-TEXT
               WHEN MQIA-MAX-MSG-LENGTH
                   MOVE 'MQIA-MAX-MSG-LENGTH' TO WS-TEXT
               WHEN MQIA-BACKOUT-THRESHOLD
                   MOVE 'MQIA-BACKOUT-THRESHOLD' TO WS-TEXT
               WHEN MQIA-SHAREABILITY
                   MOVE 'MQIA-SHAREABILITY' TO WS-TEXT
               WHEN MQIA-DEF-INPUT-OPEN-OPTION
                   MOVE 'MQIA-DEF-INPUT-OPEN-OPTION' TO WS-TEXT
               WHEN MQIA-HARDEN-GET-BACKOUT
                   MOVE 'MQIA-HARDEN-GET-BACKOUT' TO WS-TEXT
               WHEN MQIA-MSG-DELIVERY-SEQUENCE
                   MOVE 'MQIA-MSG-DELIVERY-SEQUENCE' TO WS-TEXT
               WHEN MQIA-RETENTION-INTERVAL
                   MOVE 'MQIA-RETENTION-INTERVAL' TO WS-TEXT
               WHEN MQIA-DEFINITION-TYPE
                   MOVE 'MQIA-DEFINITION-TYPE' TO WS-TEXT
               WHEN MQIA-USAGE
                   MOVE 'MQIA-USAGE' TO WS-TEXT
               WHEN MQIA-TRIGGER-CONTROL
                   MOVE 'MQIA-TRIGGER-CONTROL' TO WS-TEXT
               WHEN MQIA-TRIGGER-TYPE
                   MOVE 'MQIA-TRIGGER-TYPE' TO WS-TEXT
               WHEN MQIA-TRIGGER-MSG-PRIORITY
                   MOVE 'MQIA-TRIGGER-MSG-PRIORITY' TO WS-TEXT
               WHEN MQIA-TRIGGER-DEPTH
                   MOVE 'MQIA-TRIGGER-DEPTH' TO WS-TEXT
               WHEN MQIA-Q-DEPTH-HIGH-LIMIT
                   MOVE 'MQIA-Q-DEPTH-HIGH-LIMIT' TO WS-TEXT
               WHEN MQIA-Q-DEPTH-LOW-LIMIT
                   MOVE 'MQIA-Q-DEPTH-LOW-LIMIT' TO WS-TEXT
               WHEN MQIA-Q-SERVICE-INTERVAL
                   MOVE 'MQIA-Q-SERVICE-INTERVAL' TO WS-TEXT
               WHEN MQIA-DEF-BIND
                   MOVE 'MQIA-DEF-BIND' TO WS-TEXT
               WHEN MQIA-INDEX-TYPE
                   MOVE 'MQIA-INDEX-TYPE' TO WS-TEXT
      *
      * Starting Queue Manager Attributes
      *
               WHEN MQIA-PLATFORM
                   MOVE 'MQIA-PLATFORM' TO WS-TEXT
               WHEN MQIA-COMMAND-LEVEL
                   MOVE 'MQIA-COMMAND-LEVEL' TO WS-TEXT
               WHEN MQIA-CPI-LEVEL
                   MOVE 'MQIA-CPI-LEVEL' TO WS-TEXT
               WHEN MQIA-IGQ-PUT-AUTHORITY
                   MOVE 'MQIA-IGQ-PUT-AUTHORITY' TO WS-TEXT
               WHEN MQIA-INTRA-GROUP-QUEUING
                   MOVE 'MQIA-INTRA-GROUP-QUEUING' TO WS-TEXT
               WHEN MQIA-EXPIRY-INTERVAL
                   MOVE 'MQIA-EXPIRY-INTERVAL' TO WS-TEXT
               WHEN MQIA-SSL-TASKS
                   MOVE 'MQIA-SSL-TASKS' TO WS-TEXT
               WHEN MQIA-CONFIGURATION-EVENT
                   MOVE 'MQIA-CONFIGURATION-EVENT' TO WS-TEXT
               WHEN MQIA-TRIGGER-INTERVAL
                   MOVE 'MQIA-TRIGGER-INTERVAL' TO WS-TEXT
               WHEN MQIA-MAX-PRIORITY
                   MOVE 'MQIA-MAX-PRIORITY' TO WS-TEXT
               WHEN MQIA-CODED-CHAR-SET-ID
                   MOVE 'MQIA-CODED-CHAR-SET-ID' TO WS-TEXT
               WHEN MQIA-MAX-HANDLES
                   MOVE 'MQIA-MAX-HANDLES' TO WS-TEXT
               WHEN MQIA-MAX-UNCOMMITTED-MSGS
                   MOVE 'MQIA-MAX-UNCOMMITTED-MSGS' TO WS-TEXT
               WHEN MQIA-MAX-MSG-LENGTH
                   MOVE 'MQIA-MAX-MSG-LENGTH' TO WS-TEXT
               WHEN MQIA-SYNCPOINT
                   MOVE 'MQIA-SYNCPOINT' TO WS-TEXT
               WHEN MQIA-AUTHORITY-EVENT
                   MOVE 'MQIA-AUTHORITY-EVENT' TO WS-TEXT
               WHEN MQIA-INHIBIT-EVENT
                   MOVE 'MQIA-INHIBIT-EVENT' TO WS-TEXT
               WHEN MQIA-LOCAL-EVENT
                   MOVE 'MQIA-LOCAL-EVENT' TO WS-TEXT
               WHEN MQIA-REMOTE-EVENT
                   MOVE 'MQIA-REMOTE-EVENT' TO WS-TEXT
               WHEN MQIA-START-STOP-EVENT
                   MOVE 'MQIA-START-STOP-EVENT' TO WS-TEXT
               WHEN MQIA-PERFORMANCE-EVENT
                   MOVE 'MQIA-PERFORMANCE-EVENT' TO WS-TEXT
      *
      * Starting Storage Class Attributes
      *
               WHEN MQIA-PAGESET-ID
                   MOVE 'MQIA-PAGESET-ID' TO WS-TEXT
      *
      * Default
      *
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
      *
       MQCFIN-PARAMETER-LITERAL-END.
           EXIT.
      *
       MQCFIN-VALUE-LITERAL SECTION.
      ******************************************************************
      * Set up the Value description for MQCFIN
      ******************************************************************
      *
      * Starting General Attributes
      *
           MOVE SPACES TO WS-TEXT.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-APPL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQAT-CICS
                      MOVE 'CICS' TO WS-TEXT
                  WHEN MQAT-IMS
                      MOVE 'IMS' TO WS-TEXT
                  WHEN MQAT-MVS
                      MOVE 'MVS BATCH' TO WS-TEXT
                  WHEN MQAT-QMGR
                      MOVE 'QMGR' TO WS-TEXT
                  WHEN MQQT-ALIAS
                      MOVE 'MQQT-ALIAS' TO WS-TEXT
                  WHEN MQQT-REMOTE
                      MOVE 'MQQT-REMOTE' TO WS-TEXT
                  WHEN MQRQ-Q-MGR-QUIESCING
                      MOVE 'MQRQ-Q-MGR-QUIESCING' TO WS-TEXT
                  WHEN MQRQ-Q-MGR-STOPPING
                      MOVE 'MQRQ-Q-MGR-STOPPING ' TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-REASON-QUALIFIER
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQRQ-CHANNEL-STOPPED-OK
                      MOVE 'MQRQ-CHANNEL-OK-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-ERROR
                      MOVE 'MQRQ-CHANNEL-ERROR-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-RETRY
                      MOVE 'MQRQ-CHANNEL-RETRY-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-DISABLED
                      MOVE 'MQRQ-CHANNEL-DISABLED-STOP' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-Q-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQT-LOCAL
                      MOVE 'LOCAL QUEUE' TO WS-TEXT
                  WHEN MQQT-MODEL
                      MOVE 'MODEL QUEUE' TO WS-TEXT
                  WHEN MQQT-ALIAS
                      MOVE 'ALIAS QUEUE' TO WS-TEXT
                  WHEN MQQT-REMOTE
                      MOVE 'REMOTE QUEUE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-EVENT-ORIGIN
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVO-CONSOLE
                      MOVE 'CONSOLE' TO WS-TEXT
                  WHEN MQEVO-INIT
                      MOVE 'INIT' TO WS-TEXT
                  WHEN MQEVO-MSG
                      MOVE 'MSG' TO WS-TEXT
                  WHEN MQEVO-MQSET
                      MOVE 'MQSET' TO WS-TEXT
                  WHEN MQEVO-INTERNAL
                      MOVE 'INTERNAL' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-OBJECT-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQOT-CHANNEL
                      MOVE 'CHANNEL' TO WS-TEXT
                  WHEN MQOT-NAMELIST
                      MOVE 'NAMELIST' TO WS-TEXT
                  WHEN MQOT-PROCESS
                      MOVE 'PROCESS' TO WS-TEXT
                  WHEN MQOT-Q
                      MOVE 'QUEUE' TO WS-TEXT
                  WHEN MQOT-STORAGE-CLASS
                      MOVE 'STORAGE CLASS' TO WS-TEXT
                  WHEN MQOT-Q-MGR
                      MOVE 'QUEUE MANAGER' TO WS-TEXT
                  WHEN MQOT-AUTH-INFO
                      MOVE 'AUTHENTICATION INFORMATION' TO WS-TEXT
                  WHEN MQOT-CF-STRUC
                      MOVE 'CF STRUCTURE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-QSG-DISP
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQSGD-Q-MGR
                      MOVE 'QUEUE MANAGER' TO WS-TEXT
                  WHEN MQQSGD-SHARED
                      MOVE 'SHARED' TO WS-TEXT
                  WHEN MQQSGD-GROUP
                      MOVE 'GROUP' TO WS-TEXT
                  WHEN MQQSGD-COPY
                      MOVE 'COPY' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-CHANNEL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQCHT-SENDER
                      MOVE 'SENDER' TO WS-TEXT
                  WHEN MQCHT-SERVER
                      MOVE 'SERVER' TO WS-TEXT
                  WHEN MQCHT-RECEIVER
                      MOVE 'RECEIVER' TO WS-TEXT
                  WHEN MQCHT-REQUESTER
                      MOVE 'REQUESTER' TO WS-TEXT
                  WHEN MQCHT-SVRCONN
                      MOVE 'SVRCONN' TO WS-TEXT
                  WHEN MQCHT-CLNTCONN
                      MOVE 'CLNTCONN' TO WS-TEXT
                  WHEN MQCHT-CLUSRCVR
                      MOVE 'CLUSRCVR' TO WS-TEXT
                  WHEN MQCHT-CLUSSDR
                      MOVE 'CLUSSDR' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-XMIT-PROTOCOL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQXPT-LU62
                      MOVE 'LU 6.2' TO WS-TEXT
                  WHEN MQXPT-TCP
                      MOVE 'TCP' TO WS-TEXT
                  WHEN MQXPT-NETBIOS
                      MOVE 'NETBIOS' TO WS-TEXT
                  WHEN MQXPT-SPX
                      MOVE 'SPX' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-DATA-CONVERSION
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQCDC-NO-SENDER-CONVERSION
                      MOVE 'NO CONVERSION BY SENDER' TO WS-TEXT
                  WHEN MQCDC-SENDER-CONVERSION
                      MOVE 'CONVERSION BY SENDER' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-PUT-AUTHORITY
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQPA-DEFAULT
                      MOVE 'DEFAULT' TO WS-TEXT
                  WHEN MQPA-CONTEXT
                      MOVE 'CONTEXT' TO WS-TEXT
                  WHEN MQPA-ALTERNATE-OR-MCA
                      MOVE 'ALTERNATE OR MCA' TO WS-TEXT
                  WHEN MQPA-ONLY-MCA
                      MOVE 'ONLY MCA' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-MCA-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQMCAT-PROCESS
                      MOVE 'PROCESS' TO WS-TEXT
                  WHEN MQMCAT-THREAD
                      MOVE 'THREAD' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-NPM-SPEED
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQNPMS-NORMAL
                      MOVE 'NORMAL SPEED' TO WS-TEXT
                  WHEN MQNPMS-FAST
                      MOVE 'FAST SPEED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-SSL-CLIENT-AUTH
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQSCA-REQUIRED
                      MOVE 'CERTIFICATE REQUIRED' TO WS-TEXT
                  WHEN MQSCA-OPTIONAL
                      MOVE 'CERTIFICATE OPTIONAL' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-INHIBIT-GET
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQA-GET-ALLOWED
                      MOVE 'GET OPERATIONS ALLOWED' TO WS-TEXT
                  WHEN MQQA-GET-INHIBITED
                      MOVE 'GET OPERATIONS INHIBITED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-INHIBIT-PUT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQA-PUT-ALLOWED
                      MOVE 'PUT OPERATIONS ALLOWED' TO WS-TEXT
                  WHEN MQQA-PUT-INHIBITED
                      MOVE 'PUT OPERATIONS INHIBITED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-DEF-PERSISTENCE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQPER-PERSISTENT
                      MOVE 'MESSAGE IS PERSISTENT' TO WS-TEXT
                  WHEN MQPER-NOT-PERSISTENT
                      MOVE 'MESSAGE IS NOT PERSISTENT' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-SHAREABILITY
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQA-SHAREABLE
                      MOVE 'QUEUE IS SHAREABLE' TO WS-TEXT
                  WHEN MQQA-NOT-SHAREABLE
                      MOVE 'QUEUE IS NOT SHAREABLE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-DEF-INPUT-OPEN-OPTION
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQOO-INPUT-EXCLUSIVE
                      MOVE 'EXCLUSIVE ACCESS' TO WS-TEXT
                  WHEN MQOO-INPUT-SHARED
                      MOVE 'SHARED ACCESS' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-HARDEN-GET-BACKOUT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQA-BACKOUT-HARDENED
                      MOVE 'BACKOUT COUNT REMEMBERED' TO WS-TEXT
                  WHEN MQQA-BACKOUT-NOT-HARDENED
                      MOVE 'BACKOUT COUNT NOT REMEMBERED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-MSG-DELIVERY-SEQUENCE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQMDS-PRIORITY
                      MOVE 'RETURNED IN PRIORITY ORDER' TO WS-TEXT
                  WHEN MQMDS-FIFO
                      MOVE 'RETURNED IN FIFO ORDER' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-DEFINITION-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQDT-PREDEFINED
                      MOVE 'PREDEFINED PERMANENT QUEUE' TO WS-TEXT
                  WHEN MQQDT-PERMANENT-DYNAMIC
                      MOVE 'DYNAMIC DEFINED QUEUE' TO WS-TEXT
                  WHEN MQQDT-SHARED-DYNAMIC
                      MOVE 'DYNAMIC DEFINED SHARED QUEUE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-USAGE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQUS-NORMAL
                      MOVE 'NORMAL USAGE' TO WS-TEXT
                  WHEN MQUS-TRANSMISSION
                      MOVE 'TRANSMISSION QUEUE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-TRIGGER-CONTROL
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQTC-OFF
                      MOVE 'TRIGGER MESSAGES NOT REQUIRED' TO WS-TEXT
                  WHEN MQTC-ON
                      MOVE 'TRIGGER MESSAGES REQUIRED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-TRIGGER-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQTT-NONE
                      MOVE 'NO TRIGGER MESSAGES' TO WS-TEXT
                  WHEN MQTT-FIRST
                      MOVE 'TRIGGER MESSAGE FIRST' TO WS-TEXT
                  WHEN MQTT-EVERY
                      MOVE 'TRIGGER MESSAGE EVERY' TO WS-TEXT
                  WHEN MQTT-DEPTH
                      MOVE 'TRIGGER MESSAGE DEPTH' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-DEF-BIND
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQBND-BIND-ON-OPEN
                      MOVE 'FIXED BY OPEN CALL' TO WS-TEXT
                  WHEN MQBND-BIND-NOT-FIXED
                      MOVE 'NOT FIXED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-AUTHORITY-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-INHIBIT-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-LOCAL-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-REMOTE-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-START-STOP-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-PERFORMANCE-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-CONFIGURATION-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-DISABLED
                      MOVE 'EVENT REPORTING DISABLED' TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'EVENT REPORTING ENABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
       MQCFIN-VALUE-LITERAL-END.
           EXIT.
      *
       MQCFSL-PARAMETER-LITERAL SECTION.
      ******************************************************************
      * Set up the Parameter description for MQCFSL
      ******************************************************************
      *
      * Starting Channel Attributes
      *
           MOVE SPACES TO WS-TEXT.
      *
           EVALUATE MQCFSL-PARAMETER OF MQCFSL
               WHEN MQCACH-MSG-EXIT-NAME
                   MOVE 'MQCACH-MSG-EXIT-NAME' TO WS-TEXT
               WHEN MQCACH-SEND-EXIT-NAME
                   MOVE 'MQCACH-SEND-EXIT-NAME' TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-NAME
                   MOVE 'MQCACH-RCV-EXIT-NAME' TO WS-TEXT
               WHEN MQCACH-MSG-EXIT-USER-DATA
                   MOVE 'MQCACH-MSG-EXIT-USER-DATA' TO WS-TEXT
               WHEN MQCACH-SEND-EXIT-USER-DATA
                   MOVE 'MQCACH-SEND-EXIT-USER-DATA' TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-USER-DATA
                   MOVE 'MQCACH-RCV-EXIT-USER-DATA' TO WS-TEXT
               WHEN MQCA-CLUSTER-NAMELIST
                   MOVE 'MQCA-CLUSTER-NAMELIST' TO WS-TEXT
      *
      * Starting Namelist Attributes
      *
               WHEN MQCA-NAMES
                   MOVE 'MQCA-NAMES' TO WS-TEXT
      *
      * Default
      *
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
      *
       MQCFSL-PARAMETER-LITERAL-END.
           EXIT.
      *
      * ---------------------------------------------------------------
      *                  End of program
      * ---------------------------------------------------------------
