CBL NODYNAM,LIB,OBJECT,RENT,RES,APOST
      *                                                               *
      * ------------------------------------------------------------- *
       IDENTIFICATION DIVISION.
      * ------------------------------------------------------------- *
       PROGRAM-ID. READPCF.
      *REMARKS
      *****************************************************************
      *  Module Name      : READPCF                                   *
      *                                                               *
      *  Environment      : z/OS Batch; COBOL II                      *
      *                                                               *
      *  Description      : Test program to print EVENT messages from *
      *                     specified event queue.                    *
      *                                                               *
      *  Limitations      : Tested with the following event types:    *
      *                     Configuration events                      *
      *                     Command       events                      *
      *                     Queue Mgr     events                      *
      *                     Start/stop    events (channel)            *
      *                                                               *
      *                     Based on another program, some            *
      *                     declarations may be unused.               *
      *                                                               *
      *  Function         : This program prints a report showing all  *
      *                     fields of the EVENT messages from a       *
      *                     specified queue and queue manager         *
      *                                                               *
      *  Requires         : WebSphere MQ for z/OS copybooks (6.0)     *
      *                                                               *
      * ************************************************************* *
      * ------------------------------------------------------------- *
       ENVIRONMENT DIVISION.
      * ------------------------------------------------------------- *
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
      * ------------------------------------------------------------- *
       DATA DIVISION.
      * ------------------------------------------------------------- *
       FILE SECTION.
      * ------------------------------------------------------------- *
       WORKING-STORAGE SECTION.
      * ------------------------------------------------------------- *
      *
      *    W00 - General work fields
      *
       01  W00-MESSAGE-COUNT           PIC s9(9) BINARY  VALUE ZERO.
       01  W00-DATE.
           05  W00-YY                  PIC 99.
           05  W00-MM                  PIC 99.
           05  W00-DD                  PIC 99.
       01  W00-PRINT-DATA              PIC X(132).
       01  W00-RETURN-CODE             PIC S9(04) BINARY  VALUE ZERO.
      *
      *    W01 - Lines of the print report
      *
       01  W01-HEADER-1.
           05  FILLER                  PIC X(10) VALUE SPACES.
           05  W01-MM                  PIC 99.
           05  FILLER                  PIC X     VALUE '/'.
           05  W01-DD                  PIC 99.
           05  FILLER                  PIC X     VALUE '/'.
           05  W01-YY                  PIC 99.
           05  FILLER                  PIC X(8) VALUE SPACES.
           05  FILLER                  PIC X(20) VALUE
                                                 'EVENT MESSAGE REPORT'.
           05  FILLER                  PIC X(37) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE SPACES.
           05  FILLER                  PIC X(10) VALUE SPACES.
       01  W01-HEADER-2.
           05  FILLER                  PIC X(5) VALUE SPACES.
           05  FILLER                  PIC X(29) VALUE
                                       '        QUEUE MANAGER NAME : '.
           05  W01-MQM-NAME            PIC X(48) VALUE SPACES.
           05  FILLER                  PIC X(30) VALUE SPACES.
       01  W01-HEADER-3.
           05  FILLER                  PIC X(17) VALUE SPACES.
           05  FILLER                  PIC X(17) VALUE
                                                    '    QUEUE NAME : '.
           05  W01-QUEUE-NAME          PIC X(48) VALUE SPACES.
           05  FILLER                  PIC X(30) VALUE SPACES.
       01  W01-HEADER-4.
           05  FILLER                  PIC X(16)  VALUE SPACES.
           05  FILLER                  PIC X(116) VALUE SPACES.
      *
      *    W02 - Data fields derived from the PARM field
      *
       01  W02-MQM                     PIC X(48) VALUE SPACES.
       01  W02-OBJECT                  PIC X(48) VALUE SPACES.
      *
      *    W03 - MQM API fields
      *
       01  W03-BUFFER-LENGTH           PIC S9(9) BINARY  VALUE 400000.
       01  W03-HCONN                   PIC S9(9) BINARY.
       01  W03-OPTIONS                 PIC S9(9) BINARY.
       01  W03-HOBJ                    PIC S9(9) BINARY.
       01  W03-DATA-LENGTH             PIC S9(9) BINARY.
       01  W03-COMPCODE                PIC S9(9) BINARY.
       01  W03-REASON                  PIC S9(9) BINARY.
       01  W03-MESSAGE-DATA            PIC X(400000) VALUE SPACES.
      *
      *    W04 - Error and information messages
      *
       01  W04-MESSAGE-0.
           05  FILLER              PIC X(28) VALUE SPACES.
           05  FILLER              PIC X(35) VALUE
                                  '********** END OF REPORT **********'.
           05  FILLER              PIC X(49) VALUE SPACES.
       01  W04-MESSAGE-1.
           05  FILLER              PIC X(1)  VALUE SPACES.
           05  FILLER              PIC X(122) VALUE
              '********** NO DATA PASSED TO PROGRAM. PROGRAM REQUIRES A
      -       'QUEUE MANAGER NAME AND A QUEUE NAME. **********'.
       01  W04-MESSAGE-2.
           05  FILLER              PIC X(5)  VALUE SPACES.
           05  FILLER              PIC X(107) VALUE
              '********** NO QUEUE MANAGER NAME PASSED TO PROGRAM - DEFA
      -       'ULT USED *****'.
       01  W04-MESSAGE-3.
           05  FILLER              PIC X(18) VALUE SPACES.
           05  FILLER              PIC X(94) VALUE
              '********** NO QUEUE NAME PASSED TO PROGRAM. **********'.
       01  W04-MESSAGE-4.
           05  FILLER              PIC X(1) VALUE SPACES.
           05  FILLER              PIC X(32) VALUE
                   '********** AN ERROR OCCURRED IN '.
           05  W04-MSG4-TYPE       PIC X(10).
           05  FILLER              PIC X(20) VALUE
                   '. COMPLETION CODE = '.
           05  W04-MSG4-COMPCODE   PIC Z(8)9.
           05  FILLER              PIC X(15) VALUE ' REASON CODE ='.
           05  W04-MSG4-REASON     PIC Z(8)9.
           05  FILLER              PIC X(24) VALUE ' **********'.
      *
      *    The following copy files define API control blocks.
      *
       01  W05-MQM-OBJECT-DESCRIPTOR.
           COPY CMQODV.
       01  W05-MQM-MESSAGE-DESCRIPTOR.
           COPY CMQMDV.
       01  W05-MQM-GET-MESSAGE-OPTIONS.
           COPY CMQGMOV.
      *
      *    Copy file of constants (for filling in the control blocks)
      *    and return codes (for testing the result of a call)
      *
       01  W05-MQM-CONSTANTS.
           COPY CMQV.
      *
       01  W05-MQM-CHINIT-CONSTANTS.
           COPY CMQXV.
      *
      *    W06 - Return values
      *
       01  W06-CSQ4-OK             PIC S9(4) VALUE 0.
       01  W06-CSQ4-WARNING        PIC S9(4) VALUE 4.
       01  W06-CSQ4-ERROR          PIC S9(4) VALUE 8.
      *
      * call parameters for program UTIMEDSP
       01  WS-UTIMEDSP.
           05 WS-UTIMEDSP-STCK        PIC X(8).
           05 WS-UTIMEDSP-DISPLAY     PIC X(12).
       01  WS-BLANK9                  PIC X(9) VALUE SPACES.
      *
      * date/time data descriptions
       01  WS-DATE.
           05 WS-DATE-YY              PIC 99.
           05 WS-DATE-MM              PIC 99.
           05 WS-DATE-DD              PIC 99.
       01  WS-TIME.
           05 WS-TIME-HOUR            PIC 99.
           05 WS-TIME-MIN             PIC 99.
           05 WS-TIME-SEC             PIC 99.
           05 WS-TIME-HUND            PIC 99.
       01  WS-TIME1.
           05 WS-TIME1-HOUR           PIC 99.
           05 WS-TIME1-MIN            PIC 99.
           05 WS-TIME1-SEC            PIC 99.
           05 WS-TIME1-HUND           PIC 99.
       01  WS-TIME2.
           05 WS-TIME2-HOUR           PIC 99.
           05 WS-TIME2-MIN            PIC 99.
           05 WS-TIME2-SEC            PIC 99.
           05 WS-TIME2-HUND           PIC 99.
       01  WS-TIME-TOTAL              PIC 9(8).
       01  WS-TIME-TOTAL1             PIC 9(8).
       01  WS-TIME-TOTAL2             PIC 9(8).
       01  WS-DAY-OF-WEEK             PIC 9.
       01  WS-DAY.
           05 WS-DAY-YY               PIC 99.
           05 WS-DAY-DDD              PIC 999.
      * work areas for MQSeries api calls
      *
       01  WS-NAME                    PIC X(48).
       01  WS-HCONN                   PIC S9(9) BINARY.
       01  WS-HOBJ                    PIC S9(9) BINARY.
       01  WS-BUFFLEN                 PIC S9(9) BINARY VALUE ZEROS.
       01  WS-DATALEN                 PIC S9(9) BINARY VALUE ZEROS.
       01  WS-OPTIONS                 PIC S9(9) BINARY.
       01  WS-INTCOUNT                PIC S9(9) BINARY.
       01  WS-SELCOUNT                PIC S9(9) BINARY.
       01  WS-CHARCOUNT               PIC S9(9) BINARY.
       01  WS-CHARLEN                 PIC S9(9) BINARY.
       01  WS-SEL                     PIC S9(9) BINARY.
       01  WS-VERSION                 PIC S9(9) BINARY.
       01  WS-COMPCODE                PIC S9(9) BINARY.
       01  WS-REASON                  PIC S9(9) BINARY.
       01  WS-BUFFER-AREA.
           05 WS-BUFFER-AREA-CHAR     PIC X OCCURS 4194304.
       01  WS-BIN-NUMBERS1.
           05 WS-BIN-NUM1             PIC S9(9) BINARY OCCURS 100.
       01  WS-BIN-NUMBERS2.
           05 WS-BIN-NUM2             PIC S9(9) BINARY OCCURS 100.
      *
      * work areas for MQ API calls end
      *
      *
       01  WS-TIME-DISPLAY.
           05 WS-TIME-DISPLAY-HOUR    PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-MIN     PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-SEC     PIC 99.
           05 FILLER                  PIC X VALUE ':'.
           05 WS-TIME-DISPLAY-HUND    PIC 99.
      *
       01  WS-TEXT-TITLE              PIC X(30) VALUE SPACES.
       01  WS-TEXT                    PIC X(30) VALUE SPACES.
       01  WS-XTOCHAR-LEN             PIC S9(9) COMP VALUE ZEROS.
       01  WS-LONG-HEXDISP            PIC X(8).
      *
      ******************************************************************
      * Declare a work buffer for processing a sub-structure within the
      * PCF message.
      ******************************************************************
       01  WORK-BUF PIC X(1000).
      * MQCFH substructure
       01  CFH-BUF REDEFINES WORK-BUF.
        02  CFH-HDR.
            COPY CMQCFHL.
      * MQCFIN substructure
       01  CFIN-BUF REDEFINES WORK-BUF.
        02  CFIN-HDR.
            COPY CMQCFINL.
      * MQCFIL substructure
       01  CFIL-BUF REDEFINES WORK-BUF.
        02  CFIL-HDR.
            COPY CMQCFILL.
        02  CFIL-DATA PIC S9(9) BINARY OCCURS 50 TIMES.
      * MQCFST substructure
       01  CFST-BUF REDEFINES WORK-BUF.
        02  CFST-HDR.
            COPY CMQCFSTL.
        02  CFST-DATA PIC X(64).
      * MQCFSL substructure
       01  CFSL-BUF REDEFINES WORK-BUF.
        02  CFSL-HDR.
            COPY CMQCFSLL.
        02  CFSL-DATA PIC X(400).
      * MQCFGR substructure
       01  CFGR-BUF REDEFINES WORK-BUF.
        02  CFGR-HDR.
            COPY CMQCFGRL.
        02  CFGR-DATA PIC X(64).
      * MQCFBS substructure
       01  CFBS-BUF REDEFINES WORK-BUF.
        02  CFBS-HDR.
            COPY CMQCFBSL.
        02  CFBS-DATA PIC X(64).
      *
      ******************************************************************
      * Declare certain variables as both char and num. (PCF processing)
      ******************************************************************
      * Structure length
       01  STRUC-LEN-CHAR.
        02  STRUC-LEN PIC S9(9) BINARY.
            88 WS-START-MESSAGE VALUE 2282.
            88 WS-STOP-MESSAGE  VALUE 2283.
      *
      ******************************************************************
      * Declare other simple variables. (PCF processing)
      ******************************************************************
       01  WS-PCF.
        10  FIRST-BYTE PIC S9(9) BINARY.
        10  PARM-COUNT PIC S9(9) BINARY.
        10  G-PARM-COUNT PIC S9(9) BINARY.
        10  J          PIC S9(9) BINARY.
        10  K          PIC S9(9) BINARY.
        10  L          PIC S9(9) BINARY.
        10  N          PIC S9(9) BINARY.
       01 NOT-EVENT PIC S9(9) BINARY VALUE 0.
       01 IS-EVENT PIC S9(9) BINARY VALUE 4.
       01 EVENT-OPTION PIC S9(9) BINARY.
       01 YES-NO-OPTION PIC S9(9) BINARY.
      *
       01  MQ-PCF-CONS.
           COPY CMQCFV.
      *
      *
      *
      * ------------------------------------------------------------- *
       LINKAGE SECTION.
      * ------------------------------------------------------------- *
       01  PARMDATA.
           05  PARM-LEN                PIC S9(03) BINARY.
           05  PARM-STRING             PIC X(100).
      *
           EJECT
      * ------------------------------------------------------------- *
       PROCEDURE DIVISION USING PARMDATA.
      * ------------------------------------------------------------- *
      * ------------------------------------------------------------- *
       A-MAIN SECTION.
      * ------------------------------------------------------------- *
      *
           ACCEPT W00-DATE FROM DATE.
           MOVE W00-MM TO W01-MM.
           MOVE W00-DD TO W01-DD.
           MOVE W00-YY TO W01-YY.
      *
           DISPLAY '================================================'
                   '================================================'.
           DISPLAY W01-HEADER-1.
      *
           PERFORM ACCEPT-TIME.
           DISPLAY '          ' WS-TIME-DISPLAY.
      *
      *    If no data was passed, create a message, print it, and
      *    exit
      *
           IF PARM-LEN = 0 THEN
              DISPLAY W04-MESSAGE-1
              MOVE W06-CSQ4-WARNING TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Separate into the relevant fields any data passed in the
      *    PARM statement
      *
           UNSTRING PARM-STRING DELIMITED BY ALL ','
                                   INTO W02-MQM
                                        W02-OBJECT.
      *
      *    Move the data (spaces if nothing is entered) into the
      *    relevant print fields
      *
           MOVE W02-MQM    TO W01-MQM-NAME.
           MOVE W02-OBJECT TO W01-QUEUE-NAME.
      *
      *    Print a message if the queue manager name is missing, the
      *    default queue manager will be used
      *
           IF W02-MQM = SPACES OR W02-MQM = LOW-VALUES THEN
              DISPLAY W04-MESSAGE-2
           END-IF.
      *
      *    Print a message if the queue name is missing and exit from
      *    program
      *
           IF W02-OBJECT = SPACES OR W02-OBJECT = LOW-VALUES THEN
              DISPLAY W04-MESSAGE-3
              MOVE W06-CSQ4-WARNING TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Print the remaining header lines
      *
           DISPLAY W01-HEADER-2.
           DISPLAY W01-HEADER-3.
           DISPLAY W01-HEADER-4.
      *
      *    Connect to the specified queue manager.
      *
           CALL 'MQCONN' USING W02-MQM
                               W03-HCONN
                               W03-COMPCODE
                               W03-REASON.
      *
      *    Test the output of the connect call.  If the call failed,
      *    print an error message showing the completion code and
      *    reason code
      *
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'CONNECT'     TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
              GO TO A-MAIN-END
           END-IF.
      *
      *    Initialize the object descriptor (MQOD) control block.
      *    (The copy file initializes all the other fields)
      *
           MOVE MQOT-Q            TO MQOD-OBJECTTYPE.
           MOVE W02-OBJECT        TO MQOD-OBJECTNAME.
      *
      *    Initialize the working storage fields required to open
      *    the queue
      *
           MOVE MQOO-BROWSE       TO W03-OPTIONS.
      *
      *    Open the queue.
      *
           CALL 'MQOPEN' USING W03-HCONN
                               MQOD
                               W03-OPTIONS
                               W03-HOBJ
                               W03-COMPCODE
                               W03-REASON.
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'OPEN'        TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
              GO TO A-MAIN-DISCONNECT
           END-IF.
      *
      *    Initialize the Get Message Options (MQGMO) control block.
      *    (The copy file initializes all the other fields)
      *
           MOVE MQGMO-NO-WAIT              TO MQGMO-OPTIONS.
           ADD  MQGMO-ACCEPT-TRUNCATED-MSG TO MQGMO-OPTIONS.
           ADD  MQGMO-BROWSE-FIRST         TO MQGMO-OPTIONS.
      *
      *    Make the first get call outside the loop because this call
      *    uses the BROWSE-FIRST option
      *
           CALL 'MQGET' USING W03-HCONN
                              W03-HOBJ
                              MQMD
                              MQGMO
                              W03-BUFFER-LENGTH
                              W03-MESSAGE-DATA
                              W03-DATA-LENGTH
                              W03-COMPCODE
                              W03-REASON.
      *
      *    Test the output of the get call using the PERFORM loop
      *    that follows.
      *
      *    Change the MQGMO Options field to BROWSE-NEXT.
      *
           MOVE MQGMO-NO-WAIT              TO MQGMO-OPTIONS.
           ADD  MQGMO-ACCEPT-TRUNCATED-MSG TO MQGMO-OPTIONS.
           ADD  MQGMO-BROWSE-NEXT          TO MQGMO-OPTIONS.
      *
      *    Loop from here to END-PERFORM until the get call fails
      *
           PERFORM WITH TEST BEFORE
                   UNTIL W03-COMPCODE NOT = MQCC-OK
      *
      *       Increment the relative message number.  Move the message
      *       number and the message data into the print line
      *
              ADD 1                  TO W00-MESSAGE-COUNT
              DISPLAY '*********************************************'
              DISPLAY 'Message number ' W00-MESSAGE-COUNT
      *
      *       Print the message line
      *
              PERFORM DISPLAY-MESSAGE
      *
      *
              MOVE MQMI-NONE TO MQMD-MSGID
              MOVE MQCI-NONE TO MQMD-CORRELID
      *
      *    Clear the message data field before the next get call to
      *    ensure that no old data remains if the next line is shorter
      *
              MOVE SPACES TO W03-MESSAGE-DATA
      *
      *       Get the next message
      *
              CALL 'MQGET' USING W03-HCONN
                                 W03-HOBJ
                                 MQMD
                                 MQGMO
                                 W03-BUFFER-LENGTH
                                 W03-MESSAGE-DATA
                                 W03-DATA-LENGTH
                                 W03-COMPCODE
                                 W03-REASON
      *
      *       Test the output of the MQGET call at the top of the loop.
      *       Exit the loop if an error occurs
      *
           END-PERFORM.
      *
      *
           IF (W03-COMPCODE = MQCC-FAILED)  AND
              (W03-REASON = MQRC-NO-MSG-AVAILABLE) THEN
      *
              DISPLAY W04-MESSAGE-0
      *
           ELSE
              MOVE 'GET'         TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
              MOVE W06-CSQ4-ERROR TO W00-RETURN-CODE
           END-IF.
      *
       A-MAIN-DISCONNECT.
           CALL 'MQDISC' USING W03-HCONN
                               W03-COMPCODE
                               W03-REASON.
      *
           IF (W03-COMPCODE NOT = MQCC-OK) THEN
              MOVE 'DISCONNECT'  TO W04-MSG4-TYPE
              MOVE W03-COMPCODE  TO W04-MSG4-COMPCODE
              MOVE W03-REASON    TO W04-MSG4-REASON
              DISPLAY W04-MESSAGE-4
           END-IF.
      *
       A-MAIN-END.
      *
      *    Set the return code
      *
           MOVE W00-RETURN-CODE TO RETURN-CODE.
      *
           STOP RUN.
      ******************************************************************
      * This program prepares to analyse the PCF message in COBOL,
      ******************************************************************
       DISPLAY-MESSAGE SECTION.
      *
      * Check msg is a valid PCF reply message
           MOVE W03-MESSAGE-DATA(5:4) TO STRUC-LEN-CHAR
           IF STRUC-LEN NOT = MQCFH-STRUC-LENGTH
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      'MESSAGE IS NOT IN PCF FORMAT'
              DISPLAY WS-TIME-DISPLAY 'Invalid message format bypassed'
              GO TO DISPLAY-MESSAGE-END.
           MOVE W03-MESSAGE-DATA(9:4) TO STRUC-LEN-CHAR
           IF STRUC-LEN NOT = MQCFH-VERSION-1 AND
              STRUC-LEN NOT = MQCFH-VERSION-2 AND
              STRUC-LEN NOT = MQCFH-VERSION-3
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      'MESSAGE IS NOT IN PCF FORMAT'
              DISPLAY WS-TIME-DISPLAY 'Invalid message format bypassed'
              GO TO DISPLAY-MESSAGE-END.
      *
           MOVE W03-MESSAGE-DATA(29:4) TO STRUC-LEN-CHAR.
           MOVE MQMD-PUTTIME(1:2) TO WS-TIME-DISPLAY-HOUR.
           MOVE MQMD-PUTTIME(3:2) TO WS-TIME-DISPLAY-MIN.
           MOVE MQMD-PUTTIME(5:2) TO WS-TIME-DISPLAY-SEC.
           MOVE MQMD-PUTTIME(7:2) TO WS-TIME-DISPLAY-HUND.
      *
           EVALUATE TRUE                                                
              WHEN WS-START-MESSAGE                                     
                  DISPLAY '  START EVENT '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM START-STOP-EVENT                              
                                                             
              WHEN WS-STOP-MESSAGE                                      
                  DISPLAY '  STOP EVENT  '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM START-STOP-EVENT                              
                                                             
              WHEN OTHER                                                
                  DISPLAY '       EVENT  '                              
                          'sent on ' MQMD-PUTDATE ' at ' WS-TIME-DISPLAY
                  PERFORM ACCEPT-TIME                                   
                  PERFORM DISPLAY-EVENT-MESSAGE                         
           END-EVALUATE.                                                           
      *
       DISPLAY-MESSAGE-END.
           EXIT.
      ******************************************************************
      * This program analyses a START/STOP EVENT message
      ******************************************************************
       START-STOP-EVENT SECTION.
      *
      * Initialise index and length for processing loop
           MOVE 1 TO FIRST-BYTE.
           MOVE MQCFH-STRUC-LENGTH   TO STRUC-LEN.
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
           MOVE MQCFH-PARAMETERCOUNT TO PARM-COUNT
      *
           EVALUATE MQCFH-COMPCODE OF MQCFH
               WHEN MQCC-OK
                   MOVE 'MQCC-OK' TO WS-TEXT
               WHEN MQCC-WARNING
                   MOVE 'MQCC-WARNING' TO WS-TEXT
               WHEN MQCC-FAILED
                   MOVE 'MQCC-FAILED' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           DISPLAY '  MQCFH-COMPCODE = ' WS-TEXT.
      *
      * Process each sub-structure in msg
           PERFORM TEST BEFORE VARYING J FROM 1 BY 1
             UNTIL (J > PARM-COUNT)
      * Compute index of start of next sub-structure
           COMPUTE FIRST-BYTE = FIRST-BYTE + STRUC-LEN
      * Compute start of length field (offset 4 from start of structure)
           COMPUTE K = FIRST-BYTE + 4
      * Get length of sub-structure
           MOVE W03-MESSAGE-DATA(K:4) TO STRUC-LEN-CHAR
      * Copy sub-structure into work buffer
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
      * Process sub-structure according to type
           IF MQCFIN-TYPE = MQCFT-INTEGER THEN
              PERFORM DISPLAY-SSTOP-INT-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-INTEGER-LIST THEN
              PERFORM DISPLAY-INTEGER-LIST-STRUC
           ELSE IF MQCFST-TYPE = MQCFT-STRING THEN
              PERFORM DISPLAY-SSTOP-STRING-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-STRING-LIST THEN
              PERFORM DISPLAY-STRING-LIST-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-BYTE-STRING THEN
              PERFORM DISPLAY-BYTE-STRING-STRUC
           ELSE
              MOVE 4 TO WS-XTOCHAR-LEN 
              CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-TYPE OF MQCFIN
                                WS-LONG-HEXDISP
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-TYPE OF MQCFIN
                   ' ' WS-TEXT
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      '** MESSAGE IS NO LONGER IN PCF FORMAT **'
              GO TO START-STOP-EVENT-END
           END-IF END-IF END-IF END-IF END-IF
      * End of loop
           END-PERFORM.
      *
       START-STOP-EVENT-END.
           EXIT.
      ******************************************************************
      * This program analyses a PCF / EVENT message in COBOL,
      ******************************************************************
       DISPLAY-EVENT-MESSAGE SECTION.
      *
      * Initialise index and length for processing loop
           MOVE 1 TO FIRST-BYTE.
           MOVE MQCFH-STRUC-LENGTH   TO STRUC-LEN.
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
           MOVE MQCFH-PARAMETERCOUNT TO PARM-COUNT
      *
           PERFORM DISPLAY-HEADER-STRUC.
      *
      * Process each sub-structure in msg
           PERFORM TEST BEFORE VARYING J FROM 1 BY 1
             UNTIL (J > PARM-COUNT)
      * Compute index of start of next sub-structure
           COMPUTE FIRST-BYTE = FIRST-BYTE + STRUC-LEN
      * Compute start of length field (offset 4 from start of structure)
           COMPUTE K = FIRST-BYTE + 4
      * Get length of sub-structure
           MOVE W03-MESSAGE-DATA(K:4) TO STRUC-LEN-CHAR
      * Copy sub-structure into work buffer
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
      * Process sub-structure according to type
           IF MQCFIN-TYPE = MQCFT-INTEGER THEN
              PERFORM DISPLAY-INTEGER-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-INTEGER-LIST THEN
              PERFORM DISPLAY-INTEGER-LIST-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-STRING-LIST THEN
              PERFORM DISPLAY-STRING-LIST-STRUC
           ELSE IF MQCFST-TYPE = MQCFT-STRING THEN
              PERFORM DISPLAY-STRING-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-GROUP       THEN
              PERFORM DISPLAY-GROUP-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-BYTE-STRING THEN
              PERFORM DISPLAY-BYTE-STRING-STRUC
           ELSE
              MOVE 4 TO WS-XTOCHAR-LEN 
              CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-TYPE OF MQCFIN
                                WS-LONG-HEXDISP 
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-TYPE OF MQCFIN
                   ' ' WS-TEXT 
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      '** MESSAGE IS NO LONGER IN PCF FORMAT **'
              GO TO DISPLAY-EVENT-MESSAGE-END
           END-IF END-IF END-IF END-IF END-IF END-IF
      * End of loop
           END-PERFORM.
      *
       DISPLAY-EVENT-MESSAGE-END.
           EXIT.
      ******************************************************************
      * Process header structure.
      ******************************************************************
       DISPLAY-HEADER-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH structure'.
      *
           EVALUATE MQCFH-TYPE OF MQCFH
               WHEN MQCFT-BYTE-STRING
                   MOVE 'BYTE-STRING' TO WS-TEXT
               WHEN MQCFT-COMMAND-XR
                   MOVE 'EXTENDED-CMD' TO WS-TEXT
               WHEN MQCFT-GROUP
                   MOVE 'GROUP'   TO WS-TEXT
               WHEN MQCFT-XR-ITEM
                   MOVE 'XR ITEM' TO WS-TEXT
               WHEN MQCFT-XR-MSG
                   MOVE 'XR MSG'       TO WS-TEXT
               WHEN MQCFT-XR-SUMMARY
                   MOVE 'XR SUMMARY' TO WS-TEXT
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-TYPE OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-TYPE             ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-TYPE OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-STRUCLENGTH OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-STRUCLENGTH      ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-STRUCLENGTH OF MQCFH.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-VERSION OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-VERSION          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-VERSION OF MQCFH.
      *
           EVALUATE MQCFH-COMMAND OF MQCFH
               WHEN MQCMD-CONFIG-EVENT
                   MOVE 'CONFIGURATION EVENT' TO WS-TEXT
               WHEN MQCMD-COMMAND-EVENT
                   MOVE 'COMMAND EVENT' TO WS-TEXT
               WHEN MQCMD-LOGGER-EVENT
                   MOVE 'LOGGER EVENT' TO WS-TEXT
               WHEN MQCMD-Q-MGR-EVENT
                   MOVE 'QMGR EVENT' TO WS-TEXT
               WHEN MQCMD-PERFM-EVENT
                   MOVE 'PERFORMANCE EVENT' TO WS-TEXT
               WHEN MQCMD-CHANNEL-EVENT
                   MOVE 'CHANNEL EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '***OTHER***' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-COMMAND OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-COMMAND          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-COMMAND OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-MSGSEQNUMBER OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-MSGSEQNUMBER     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-MSGSEQNUMBER OF MQCFH.
      *
           EVALUATE MQCFH-CONTROL OF MQCFH
               WHEN MQCFC-LAST
                   MOVE 'LAST MESSAGE' TO WS-TEXT
               WHEN MQCFC-NOT-LAST
                   MOVE 'NOT LAST MESSAGE' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-CONTROL OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-CONTROL          ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-CONTROL OF MQCFH
                   ' ' WS-TEXT.
      *
           EVALUATE MQCFH-COMPCODE OF MQCFH
               WHEN MQCC-OK
                   MOVE 'MQCC-OK' TO WS-TEXT
               WHEN MQCC-WARNING
                   MOVE 'MQCC-WARNING' TO WS-TEXT
               WHEN MQCC-FAILED
                   MOVE 'MQCC-FAILED' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-COMPCODE OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-COMPCODE         ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-COMPCODE OF MQCFH
                   ' ' WS-TEXT.
      *
           EVALUATE MQCFH-REASON OF MQCFH
               WHEN MQRC-COMMAND-MQSC
                   MOVE 'MQSC COMMAND' TO WS-TEXT
               WHEN MQRC-COMMAND-PCF
                   MOVE 'PCF COMMAND'   TO WS-TEXT
               WHEN MQRC-CONFIG-CREATE-OBJECT
                   MOVE 'CREATE CONFIG' TO WS-TEXT
               WHEN MQRC-CONFIG-CHANGE-OBJECT
                   MOVE 'CHANGE CONFIG'   TO WS-TEXT
               WHEN MQRC-CONFIG-DELETE-OBJECT
                   MOVE 'DELETE CONFIG' TO WS-TEXT
               WHEN MQRC-CONFIG-REFRESH-OBJECT
                   MOVE 'REFRESH CONFIG'   TO WS-TEXT
               WHEN MQRC-GET-INHIBITED
                   MOVE 'GET INHIBITED' TO WS-TEXT
               WHEN MQRC-PUT-INHIBITED
                   MOVE 'PUT INHIBITED' TO WS-TEXT
               WHEN MQRC-ALIAS-BASE-Q-TYPE-ERROR
                   MOVE 'ALIAS BASE Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-ALIAS-BASE-Q
                   MOVE 'UNKNOWN ALIAS BASE Q' TO WS-TEXT
               WHEN MQRC-UNKNOWN-OBJECT-NAME
                   MOVE 'UNKNOWN OBJECT NAME' TO WS-TEXT
               WHEN MQRC-DEF-XMIT-Q-TYPE-ERROR
                   MOVE 'DEF XMIT Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-DEF-XMIT-Q-USAGE-ERROR
                   MOVE 'DEF XMIT Q USAGE ERROR' TO WS-TEXT
               WHEN MQRC-Q-TYPE-ERROR
                   MOVE 'Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-REMOTE-Q-NAME-ERROR
                   MOVE 'REMOTE Q NAME ERROR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-DEF-XMIT-Q
                   MOVE 'UNKNOWN DEF XMIT Q' TO WS-TEXT
               WHEN MQRC-UNKNOWN-REMOTE-Q-MGR
                   MOVE 'UNKNOWN REMOTE Q MGR' TO WS-TEXT
               WHEN MQRC-UNKNOWN-XMIT-Q
                   MOVE 'UNKNOWN XMIT Q' TO WS-TEXT
               WHEN MQRC-XMIT-Q-TYPE-ERROR
                   MOVE 'XMIT Q TYPE ERROR' TO WS-TEXT
               WHEN MQRC-XMIT-Q-USAGE-ERROR
                   MOVE 'XMIT Q USAGE ERROR' TO WS-TEXT
               WHEN MQRC-CHANNEL-STARTED
                   MOVE 'CHANNEL STARTED' TO WS-TEXT
               WHEN MQRC-CHANNEL-STOPPED
                   MOVE 'CHANNEL STOPPED' TO WS-TEXT
               WHEN MQRC-CHANNEL-STOPPED-BY-USER
                   MOVE 'CHL STOPPED BY USER'  TO WS-TEXT
               WHEN MQRC-Q-MGR-ACTIVE        
                   MOVE 'QMGR ACTIVE'            TO WS-TEXT
               WHEN MQRC-Q-MGR-NOT-ACTIVE    
                   MOVE 'QMGR INACTIVE'          TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-REASON OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-REASON           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-REASON OF MQCFH
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFH-PARAMETERCOUNT OF MQCFH
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFH-PARAMETERCOUNT   ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFH-PARAMETERCOUNT OF MQCFH.
       DISPLAY-HEADER-STRUC-END.
           EXIT.
      ******************************************************************
      * Process integer structure.
      ******************************************************************
       DISPLAY-INTEGER-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN structure'.
      *
           EVALUATE MQCFIN-TYPE OF MQCFIN
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-TYPE OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-TYPE OF MQCFIN
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-STRUCLENGTH OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-STRUCLENGTH OF MQCFIN.
      *
      * parameter
           MOVE NOT-EVENT TO EVENT-OPTION
           MOVE NOT-EVENT TO YES-NO-OPTION
           EVALUATE MQCFIN-PARAMETER OF MQCFIN
               WHEN MQIA-APPL-TYPE
                   MOVE 'MQIA-APPL-TYPE' TO WS-TEXT
               WHEN MQIA-Q-TYPE
                   MOVE 'MQIA-Q-TYPE' TO WS-TEXT
               WHEN MQIA-TIME-SINCE-RESET
                   MOVE 'MQIA-TIME-SINCE-RESET' TO WS-TEXT
               WHEN MQIA-HIGH-Q-DEPTH
                   MOVE 'MQIA-HIGH-Q-DEPTH' TO WS-TEXT
               WHEN MQIACF-COMMAND
                   MOVE 'MQIACF-COMMAND'    TO WS-TEXT
               WHEN MQIACF-EVENT-ORIGIN
                   MOVE 'MQIACF-EVENT-ORIGIN' TO WS-TEXT
               WHEN MQIA-MSG-DEQ-COUNT
                   MOVE 'MQIA-MSG-DEQ-COUNT     ' TO WS-TEXT
               WHEN MQIA-MSG-ENQ-COUNT
                   MOVE 'MQIA-MSG-ENQ-COUNT     ' TO WS-TEXT
               WHEN MQIACF-ERROR-IDENTIFIER
                   MOVE 'MQIACF-ERROR-IDENTIFIER' TO WS-TEXT
               WHEN MQIACF-REASON-QUALIFIER
                   MOVE 'MQIACF-REASON-QUALIFIER' TO WS-TEXT
               WHEN MQIACF-AUX-ERROR-DATA-INT-1
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-1' TO WS-TEXT
               WHEN MQIACF-AUX-ERROR-DATA-INT-2
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-2' TO WS-TEXT
      *
                  WHEN MQIACF-REPLACE
                      MOVE 'REPLACE'          TO WS-TEXT
                  WHEN MQIACF-OBJECT-TYPE
                      MOVE 'OBJECT-TYPE'      TO WS-TEXT
                  WHEN MQIACF-EVENT-APPL-TYPE
                      MOVE 'EVENT-APPL-TYPE'   TO WS-TEXT
                  WHEN MQIA-CODED-CHAR-SET-ID
                      MOVE 'CCSID'            TO WS-TEXT
                  WHEN MQIA-CLUSTER-WORKLOAD-LENGTH
                      MOVE 'CLUS-WORKLOAD-LEN' TO WS-TEXT
                  WHEN MQIA-COMMAND-LEVEL
                      MOVE 'COMMAND-LEVEL'    TO WS-TEXT
                  WHEN MQIA-CPI-LEVEL
                      MOVE 'CPI-LEVEL'         TO WS-TEXT
                  WHEN MQIA-IGQ-PUT-AUTHORITY
                      MOVE 'IGQ-PUT-AUTHORITY' TO WS-TEXT
                  WHEN MQIA-MAX-HANDLES
                      MOVE 'MAX-HANDLES'       TO WS-TEXT
                  WHEN MQIA-MAX-MSG-LENGTH
                      MOVE 'MAX-MSG-LENGTH'    TO WS-TEXT
                  WHEN MQIA-MAX-PRIORITY
                      MOVE 'MAX-PRIORITY'      TO WS-TEXT
                  WHEN MQIA-MAX-UNCOMMITTED-MSGS
                      MOVE 'MAX-UNCOMMITTED-MSGS' TO WS-TEXT
                  WHEN MQIA-EXPIRY-INTERVAL
                      MOVE 'EXPIRY INTERVAL'   TO WS-TEXT
                  WHEN MQIA-PLATFORM
                      MOVE 'PLATFORM'          TO WS-TEXT
                  WHEN MQIA-SYNCPOINT
                      MOVE 'SYNCPOINT'         TO WS-TEXT
                  WHEN MQIA-TRIGGER-INTERVAL
                      MOVE 'TRIGGER-INTERVAL'  TO WS-TEXT
                  WHEN MQIA-SSL-TASKS
                      MOVE 'SSL-TASKS'         TO WS-TEXT
                  WHEN MQIA-AUTHORITY-EVENT
                      MOVE 'AUTHORITY-EVENT'   TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-INHIBIT-EVENT
                      MOVE 'INHIBIT-EVENT'     TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-LOCAL-EVENT
                      MOVE 'LOCAL-EVENT'       TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-PERFORMANCE-EVENT
                      MOVE 'PERFORMANCE-EVENT' TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-REMOTE-EVENT
                      MOVE 'REMOTE-EVENT'      TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-CONFIGURATION-EVENT
                      MOVE 'CONFIG-EVENT'     TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-CHANNEL-EVENT
                      MOVE 'CHANNEL-EVENT'     TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-COMMAND-EVENT
                      MOVE 'COMMAND-EVENT'     TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-SSL-EVENT
                      MOVE 'SSL-EVENT'         TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-BRIDGE-EVENT
                      MOVE 'BRIDGE-EVENT'      TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-INTRA-GROUP-QUEUING
                      MOVE 'IGQ-QUEUING'       TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-START-STOP-EVENT
                      MOVE 'START-STOP-EVENT'  TO WS-TEXT
                      MOVE IS-EVENT TO EVENT-OPTION
                  WHEN MQIA-IP-ADDRESS-VERSION
                      MOVE 'IPADDR-VERSION'    TO WS-TEXT
                  WHEN MQIA-OUTBOUND-PORT-MIN
                      MOVE 'OUTBOUND-PORT-MIN' TO WS-TEXT
                  WHEN MQIA-OUTBOUND-PORT-MAX
                      MOVE 'OUTBOUND-PORT-MAX' TO WS-TEXT
                  WHEN MQIA-ACCOUNTING-Q
                      MOVE 'ACCTQ'             TO WS-TEXT
                  WHEN MQIA-MONITORING-Q
                      MOVE 'MONQ'              TO WS-TEXT
                  WHEN MQIA-MONITORING-CHANNEL
                      MOVE 'MONCHL'            TO WS-TEXT
                  WHEN MQIA-MONITORING-AUTO-CLUSSDR
                      MOVE 'MONACL'            TO WS-TEXT
                  WHEN MQIA-SHARED-Q-Q-MGR-NAME
                      MOVE 'SHARED-Q-QNAME'    TO WS-TEXT
                  WHEN MQIA-SSL-RESET-COUNT
                      MOVE 'SSL-RESET-COUNT'   TO WS-TEXT
                  WHEN MQIA-CHINIT-ADAPTERS
                      MOVE 'CHINIT-ADAPTERS'   TO WS-TEXT
                  WHEN MQIA-CHINIT-DISPATCHERS
                      MOVE 'CHINIT-DISPATCHERS' TO WS-TEXT
                  WHEN MQIA-ACTIVE-CHANNELS
                      MOVE 'ACTIVE-CHANNELS'   TO WS-TEXT
                  WHEN MQIA-MAX-CHANNELS
                      MOVE 'MAX-CHANNELS'      TO WS-TEXT
                  WHEN MQIA-TCP-CHANNELS
                      MOVE 'TCP-CHANNELS'      TO WS-TEXT
                  WHEN MQIA-TCP-KEEP-ALIVE
                      MOVE 'TCP-KEEP-ALIVE'    TO WS-TEXT
                      MOVE IS-EVENT TO YES-NO-OPTION
                  WHEN MQIA-TCP-STACK-TYPE
                      MOVE 'TCP-STACK-TYPE'    TO WS-TEXT
                  WHEN MQIA-LU62-CHANNELS
                      MOVE 'LU62-CHANNELS'     TO WS-TEXT
                  WHEN MQIA-DNS-WLM
                      MOVE 'DNS-WLM'           TO WS-TEXT
                      MOVE IS-EVENT TO YES-NO-OPTION
                  WHEN MQIA-LISTENER-TIMER
                      MOVE 'LISTENER-TIMER'     TO WS-TEXT
                  WHEN MQIA-RECEIVE-TIMEOUT
                      MOVE 'RECEIVE-TIMEOUT'   TO WS-TEXT
                  WHEN MQIA-RECEIVE-TIMEOUT-TYPE
                      MOVE 'RECEIVE-TIMEOUT-TYPE' TO WS-TEXT
                  WHEN MQIA-RECEIVE-TIMEOUT-MIN
                      MOVE 'RECEIVE-TIMEOUT-MIN'  TO WS-TEXT
                  WHEN MQIA-ADOPTNEWMCA-CHECK
                      MOVE 'ADOPT-NEW-MCA-CHECK' TO WS-TEXT
                  WHEN MQIA-CHINIT-TRACE-TABLE-SIZE
                      MOVE 'CHIN-TRACE-TABLE-SIZE' TO WS-TEXT
                  WHEN MQIA-CHINIT-TRACE-AUTO-START
                      MOVE 'CHIN-TRACE-AUTO-START' TO WS-TEXT
                      MOVE IS-EVENT TO YES-NO-OPTION
                  WHEN MQIA-CLWL-USEQ
                      MOVE 'CLWL-USEQ'          TO WS-TEXT
                  WHEN MQIA-CLWL-MRU-CHANNELS
                      MOVE 'CLWL-MRU-CHANNELS' TO WS-TEXT
                  WHEN MQIA-TRACE-ROUTE-RECORDING
                      MOVE 'TRACE-ROUTE-RECORDING' TO WS-TEXT
                  WHEN MQIA-ACTIVITY-RECORDING
                      MOVE 'TRACE-ACTIVITY-RECORDING' TO WS-TEXT
                  WHEN MQIA-ADOPTNEWMCA-TYPE
                      MOVE 'ADOPT-NEW-MCA-TYPE'  TO WS-TEXT
                  WHEN MQIA-QSG-DISP            
                      MOVE 'QSGDISP'                TO WS-TEXT
                  WHEN MQIA-PAGESET-ID          
                      MOVE 'PSID'                   TO WS-TEXT
                  WHEN MQIA-BACKOUT-THRESHOLD   
                      MOVE 'BACKOUT THRESHOLD'      TO WS-TEXT
                  WHEN MQIA-DEF-PRIORITY        
                      MOVE 'DEF PRIORITY'           TO WS-TEXT
                  WHEN MQIA-MAX-Q-DEPTH         
                      MOVE 'MAX Q DEPTH'            TO WS-TEXT
                  WHEN MQIA-DEFINITION-TYPE     
                      MOVE 'DEFINITION TYPE'        TO WS-TEXT
                  WHEN MQIA-Q-DEPTH-HIGH-LIMIT  
                      MOVE 'Q DEPTH HIGH LIMIT'     TO WS-TEXT
                  WHEN MQIA-Q-DEPTH-LOW-LIMIT  
                      MOVE 'Q DEPTH LOW LIMIT'     TO WS-TEXT
                  WHEN MQIA-Q-SERVICE-INTERVAL  
                      MOVE 'Q SERVICE INTERVAL'     TO WS-TEXT
                  WHEN MQIA-RETENTION-INTERVAL  
                      MOVE 'RETENTION INTERVAL'     TO WS-TEXT
                  WHEN MQIA-TRIGGER-DEPTH       
                      MOVE 'TRIGGER DEPTH'          TO WS-TEXT
                  WHEN MQIA-TRIGGER-CONTROL     
                      MOVE 'TRIGGER CONTROL'        TO WS-TEXT
                  WHEN MQIA-TRIGGER-TYPE        
                      MOVE 'TRIGGER TYPE'           TO WS-TEXT
                  WHEN MQIA-NAMELIST-TYPE        
                      MOVE 'NAMELIST-TYPE'           TO WS-TEXT
                  WHEN MQIA-NPM-CLASS           
                      MOVE 'NPM CLASS'              TO WS-TEXT
                  WHEN MQIA-TRIGGER-MSG-PRIORITY
                      MOVE 'TRIGGER MSG PRIORITY'   TO WS-TEXT
                  WHEN MQIA-INDEX-TYPE          
                      MOVE 'INDXTYPE'               TO WS-TEXT
                  WHEN MQIA-HARDEN-GET-BACKOUT  
                      MOVE 'HARDENBO'               TO WS-TEXT
                  WHEN MQIA-MSG-DELIVERY-SEQUENCE
                      MOVE 'MSG DELIVERY SEQUENCE'  TO WS-TEXT
                  WHEN MQIA-SHAREABILITY        
                      MOVE 'SHAREABILITY'           TO WS-TEXT
                  WHEN MQIA-USAGE               
                      MOVE 'USAGE'                  TO WS-TEXT
                  WHEN MQIA-INHIBIT-GET         
                      MOVE 'INHIBIT GET'            TO WS-TEXT
                  WHEN MQIA-INHIBIT-PUT         
                      MOVE 'INHIBIT PUT'            TO WS-TEXT
                  WHEN MQIA-CF-LEVEL            
                      MOVE 'CFLEVEL'                TO WS-TEXT
                  WHEN MQIA-CF-RECOVER          
                      MOVE 'CF RECOVER'             TO WS-TEXT
                  WHEN MQIA-DEF-PERSISTENCE     
                      MOVE 'DEF PERSISTENCE'        TO WS-TEXT
                  WHEN MQIA-DEF-BIND            
                      MOVE 'DEF BIND'               TO WS-TEXT
                  WHEN MQIA-CLWL-Q-RANK         
                      MOVE 'CLWLRANK'               TO WS-TEXT
                  WHEN MQIA-AUTH-INFO-TYPE      
                      MOVE 'AUTHINFO TYPE'          TO WS-TEXT
                  WHEN MQIA-CLWL-Q-PRIORITY     
                      MOVE 'CLWLPRTY'               TO WS-TEXT
                  WHEN MQIA-DEF-INPUT-OPEN-OPTION 
                      MOVE 'DEF INPUT OPEN OPTION' TO WS-TEXT
                  WHEN MQIACH-XMIT-PROTOCOL-TYPE  
                      MOVE 'CHL XMIT PROTOCOL TYPE' TO WS-TEXT
                  WHEN MQIACH-BATCH-SIZE           
                      MOVE 'CHL BATCHSZ'            TO WS-TEXT
                  WHEN MQIACH-DISC-INTERVAL       
                      MOVE 'CHL DISCINT'            TO WS-TEXT
                  WHEN MQIACH-SHORT-TIMER         
                      MOVE 'CHL SHORT TIMER'        TO WS-TEXT
                  WHEN MQIACH-SHORT-RETRY         
                      MOVE 'CHL SHORT RETRY'        TO WS-TEXT
                  WHEN MQIACH-LONG-TIMER          
                      MOVE 'CHL LONG TIMER'         TO WS-TEXT
                  WHEN MQIACH-LONG-RETRY          
                      MOVE 'CHL LONG RETRY'         TO WS-TEXT
                  WHEN MQIACH-PUT-AUTHORITY       
                      MOVE 'CHL PUT-AUTHORITY '     TO WS-TEXT
                  WHEN MQIACH-SEQUENCE-NUMBER-WRAP
                      MOVE 'CHL SEQNUM WRAP'        TO WS-TEXT
                  WHEN MQIACH-CLWL-CHANNEL-RANK   
                      MOVE 'CHL CLWLRANK'           TO WS-TEXT
                  WHEN MQIACH-CLWL-CHANNEL-PRIORITY
                      MOVE 'CHL CLWLPRTY'           TO WS-TEXT
                  WHEN MQIACH-CLWL-CHANNEL-WEIGHT 
                      MOVE 'CHL CLWLWGHT'           TO WS-TEXT
                  WHEN MQIACH-MCA-TYPE              
                      MOVE 'CHL MCATYPE'            TO WS-TEXT
                  WHEN MQIACH-NETWORK-PRIORITY    
                      MOVE 'CHL NETWORK PRIORITY'   TO WS-TEXT
                  WHEN MQIACH-MAX-MSG-LENGTH      
                      MOVE 'CHL MAX MSGLEN'         TO WS-TEXT
                  WHEN MQIACH-CHANNEL-TYPE          
                      MOVE 'CHL TYPE'               TO WS-TEXT
                  WHEN MQIACH-DATA-CONVERSION     
                      MOVE 'CHL DATA CONVERSION '   TO WS-TEXT
                  WHEN MQIACH-NPM-SPEED           
                      MOVE 'CHL NPM SPEED'          TO WS-TEXT
                  WHEN MQIACH-BATCH-INTERVAL      
                      MOVE 'CHL BATCHINT'           TO WS-TEXT
                  WHEN MQIACH-BATCH-HB            
                      MOVE 'CHL BATCH HB'           TO WS-TEXT
                  WHEN MQIACH-HB-INTERVAL         
                      MOVE 'CHL HB INTERVAL'        TO WS-TEXT
                  WHEN MQIACH-MR-COUNT            
                      MOVE 'CHL MR COUNT'           TO WS-TEXT
                  WHEN MQIACH-MR-INTERVAL         
                      MOVE 'CHL MR INTERVAL'        TO WS-TEXT
                  WHEN MQIACH-ALLOC-SLOW-TIMER    
                      MOVE 'CHL ALLOC SLOW TIMER'   TO WS-TEXT
                  WHEN MQIACH-ALLOC-FAST-TIMER    
                      MOVE 'CHL ALLOC FAST TIMER'   TO WS-TEXT
                  WHEN MQIACH-SSL-CLIENT-AUTH 
                      MOVE 'CHL SSL CLIENT AUTH'    TO WS-TEXT
                  WHEN MQIACH-KEEP-ALIVE-INTERVAL 
                      MOVE 'CHL KEEPALIVE INTERVAL' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-PARAMETER OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-PARAMETER OF MQCFIN
                   ' ' WS-TEXT.
      *
      * value
           MOVE SPACES TO WS-TEXT.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-QSG-DISP
              EVALUATE MQCFIN-VALUE OF MQCFIN                                     
                  WHEN MQQSGD-ALL      
                      MOVE 'ALL'         TO WS-TEXT
                  WHEN MQQSGD-Q-MGR   
                      MOVE 'QMGR'            TO WS-TEXT
                  WHEN MQQSGD-COPY  
                      MOVE 'COPY'           TO WS-TEXT
                  WHEN MQQSGD-SHARED 
                      MOVE 'SHARED'         TO WS-TEXT
                  WHEN MQQSGD-GROUP   
                      MOVE 'GROUP'           TO WS-TEXT
                  WHEN MQQSGD-PRIVATE
                      MOVE 'PRIVATE'        TO WS-TEXT
                  WHEN MQQSGD-LIVE   
                      MOVE 'LIVE'         TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-CHANNEL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN     
                  WHEN MQCHT-SENDER    
                      MOVE 'SDR'         TO WS-TEXT
                  WHEN MQCHT-SERVER   
                      MOVE 'SVR'            TO WS-TEXT
                  WHEN MQCHT-RECEIVER
                      MOVE 'RCVR'           TO WS-TEXT
                  WHEN MQCHT-REQUESTER
                      MOVE 'RQSTR'          TO WS-TEXT
                  WHEN MQCHT-CLNTCONN 
                      MOVE 'CLNTCONN'        TO WS-TEXT
                  WHEN MQCHT-SVRCONN 
                      MOVE 'SVRCONN'        TO WS-TEXT
                  WHEN MQCHT-CLUSRCVR
                      MOVE 'CLUSRCVR'     TO WS-TEXT
                  WHEN MQCHT-CLUSSDR 
                      MOVE 'CLUSSDR'     TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF EVENT-OPTION = IS-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVR-NO-DISPLAY
                      MOVE 'NODISPLAY'   TO WS-TEXT
                  WHEN MQEVR-EXCEPTION
                      MOVE 'EXCEPTION'       TO WS-TEXT
                  WHEN MQEVR-ENABLED
                      MOVE 'ENABLED'        TO WS-TEXT
                  WHEN MQEVR-DISABLED
                      MOVE 'DISABLED'       TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
            IF YES-NO-OPTION = IS-EVENT
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQPO-YES
                      MOVE 'YES'         TO WS-TEXT
                  WHEN MQPO-NO
                      MOVE 'NO'              TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-SHARED-Q-Q-MGR-NAME
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQSQQM-USE
                      MOVE 'USE'         TO WS-TEXT
                  WHEN MQSQQM-IGNORE
                      MOVE 'IGNORE'          TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACH-NPM-SPEED          
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQNPMS-FAST
                      MOVE 'FAST'        TO WS-TEXT
                  WHEN MQNPMS-NORMAL
                      MOVE 'NORMAL'          TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-TCP-STACK-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQTCPSTACK-SINGLE
                      MOVE 'SINGLE'      TO WS-TEXT
                  WHEN MQTCPSTACK-MULTIPLE
                      MOVE 'MULTIPLE'        TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-IGQ-PUT-AUTHORITY
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQIGQPA-DEFAULT
                      MOVE 'DEF'         TO WS-TEXT
                  WHEN MQIGQPA-CONTEXT
                      MOVE 'CTX'             TO WS-TEXT
                  WHEN MQIGQPA-ONLY-IGQ
                      MOVE 'ONLYIGQ'        TO WS-TEXT
                  WHEN MQIGQPA-ALTERNATE-OR-IGQ
                      MOVE 'ALTIGQ'         TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-CLWL-USEQ
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQCLWL-USEQ-AS-Q-MGR
                      MOVE 'QMGR'        TO WS-TEXT
                  WHEN MQCLWL-USEQ-ANY
                      MOVE 'ANY'             TO WS-TEXT
                  WHEN MQCLWL-USEQ-LOCAL
                      MOVE 'LOCAL'          TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-IGQ-PUT-AUTHORITY
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQIGQPA-DEFAULT
                      MOVE 'DEF'         TO WS-TEXT
                  WHEN MQIGQPA-CONTEXT
                      MOVE 'CTX'             TO WS-TEXT
                  WHEN MQIGQPA-ONLY-IGQ
                      MOVE 'ONLYIGQ'        TO WS-TEXT
                  WHEN MQIGQPA-ALTERNATE-OR-IGQ
                      MOVE 'ALTIGQ'         TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-ADOPTNEWMCA-CHECK
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQADOPT-CHECK-Q-MGR-NAME
                      MOVE 'QMNAME'      TO WS-TEXT
                  WHEN MQADOPT-CHECK-NET-ADDR
                      MOVE 'NETADDR'         TO WS-TEXT
                  WHEN MQADOPT-CHECK-ALL
                      MOVE 'ALL'            TO WS-TEXT
                  WHEN MQADOPT-CHECK-NONE
                      MOVE 'NONE'           TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-ADOPTNEWMCA-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQADOPT-TYPE-ALL
                      MOVE 'ALL'         TO WS-TEXT
                  WHEN MQADOPT-TYPE-NO
                      MOVE 'NO'              TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-TRACE-ROUTE-RECORDING
              OR MQCFIN-PARAMETER OF MQCFIN =
                                MQIA-ACTIVITY-RECORDING
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQRECORDING-DISABLED
                      MOVE 'DISABLED'    TO WS-TEXT
                  WHEN MQRECORDING-Q
                      MOVE 'QUEUE'           TO WS-TEXT
                  WHEN MQRECORDING-MSG
                      MOVE 'MSG'            TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-ACCOUNTING-Q OR
              MQCFIN-PARAMETER OF MQCFIN = MQIA-MONITORING-Q OR
              MQCFIN-PARAMETER OF MQCFIN = MQIA-MONITORING-CHANNEL OR
              MQCFIN-PARAMETER OF MQCFIN = MQIA-MONITORING-AUTO-CLUSSDR
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQMON-NONE
                      MOVE 'NONE'        TO WS-TEXT
                  WHEN MQMON-Q-MGR
                      MOVE 'QMGR'            TO WS-TEXT
                  WHEN MQMON-OFF
                      MOVE 'OFF'            TO WS-TEXT
                  WHEN MQMON-ON
                      MOVE 'ON'             TO WS-TEXT
                  WHEN MQMON-LOW
                      MOVE 'LOW'         TO WS-TEXT
                  WHEN MQMON-MEDIUM
                      MOVE 'MEDIUM'          TO WS-TEXT
                  WHEN MQMON-HIGH
                      MOVE 'HIGH'           TO WS-TEXT
                  WHEN MQMON-NOT-AVAILABLE
                      MOVE 'NOT AVAILABLE'  TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-EVENT-APPL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQAT-QMGR
                      MOVE 'QMGR'        TO WS-TEXT
                  WHEN MQAT-CHANNEL-INITIATOR
                      MOVE 'CHINIT'          TO WS-TEXT
                  WHEN MQAT-USER
                      MOVE 'USER'           TO WS-TEXT
                  WHEN MQAT-BATCH
                      MOVE 'BATCH'          TO WS-TEXT
                  WHEN MQAT-RRS-BATCH
                      MOVE 'RRS BATCH'   TO WS-TEXT
                  WHEN MQAT-CICS
                      MOVE 'CICS'            TO WS-TEXT
                  WHEN MQAT-IMS
                      MOVE 'IMS'            TO WS-TEXT
                  WHEN MQAT-ZOS 
                      MOVE 'z/OS'        TO WS-TEXT
                  WHEN MQAT-UNIX               
                      MOVE 'UNIX'            TO WS-TEXT
                  WHEN MQAT-WINDOWS
                      MOVE 'WINDOWS'        TO WS-TEXT
                  WHEN MQAT-JAVA 
                      MOVE 'JAVA'           TO WS-TEXT
                  WHEN MQAT-USER       
                      MOVE 'USER'        TO WS-TEXT
                  WHEN MQAT-BROKER
                      MOVE 'BROKER'          TO WS-TEXT
                  WHEN MQAT-IMS-BRIDGE
                      MOVE 'IMS BRIDGE'     TO WS-TEXT
                  WHEN MQAT-USER-LAST 
                      MOVE 'USER LAST'      TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-IP-ADDRESS-VERSION
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQIPADDR-IPV4
                      MOVE 'IPV4'        TO WS-TEXT
                  WHEN MQIPADDR-IPV6
                      MOVE 'IPV6'            TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-COMMAND
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQCMD-ARCHIVE-LOG
                      MOVE 'ARCHIVE LOG' TO WS-TEXT
                  WHEN MQCMD-BACKUP-CF-STRUC
                      MOVE 'BACKUP CFSTRUCT' TO WS-TEXT
                  WHEN MQCMD-CHANGE-AUTH-INFO
                      MOVE 'ALTER AUTHINFO' TO WS-TEXT
                  WHEN MQCMD-COPY-AUTH-INFO
                      MOVE 'COPY AUTHINFO'   TO WS-TEXT
                  WHEN MQCMD-CHANGE-BUFFER-POOL
                      MOVE 'ALTER BUFFPOOL'  TO WS-TEXT
                  WHEN MQCMD-CHANGE-CF-STRUC
                      MOVE 'ALTER CFSTRUCT' TO WS-TEXT
                  WHEN MQCMD-CHANGE-CHANNEL
                      MOVE 'ALTER  CHANNEL'  TO WS-TEXT
                  WHEN MQCMD-COPY-CHANNEL
                      MOVE 'COPY-CHANNEL'    TO WS-TEXT
                  WHEN MQCMD-PING-CHANNEL
                      MOVE 'PING-CHANNEL'    TO WS-TEXT
                  WHEN MQCMD-RESET-CHANNEL
                      MOVE 'RESET-CHANNEL'   TO WS-TEXT
                  WHEN MQCMD-CHANGE-NAMELIST
                      MOVE 'ALTER NAMELIST' TO WS-TEXT
                  WHEN MQCMD-COPY-NAMELIST
                      MOVE 'COPY-NAMELIST'   TO WS-TEXT
                  WHEN MQCMD-CHANGE-LISTENER
                      MOVE 'ALTER LISTENER'  TO WS-TEXT
                  WHEN MQCMD-CREATE-LISTENER
                      MOVE 'DEFINE LISTENER'  TO WS-TEXT
                  WHEN MQCMD-COPY-LISTENER
                      MOVE 'COPY LISTENER'  TO WS-TEXT
                  WHEN MQCMD-DELETE-LISTENER
                      MOVE 'DELETE LISTENER'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-LISTENER
                      MOVE 'DISPLAY LISTENER'  TO WS-TEXT
                  WHEN MQCMD-CHANGE-PAGE-SET
                      MOVE 'ALTER PSID'      TO WS-TEXT
                  WHEN MQCMD-CHANGE-PROCESS
                      MOVE 'ALTER PROCESS' TO WS-TEXT
                  WHEN MQCMD-COPY-PROCESS
                      MOVE 'COPY  PROCESS' TO WS-TEXT
                  WHEN MQCMD-CHANGE-Q
                      MOVE 'ALTER QUEUE'     TO WS-TEXT
                  WHEN MQCMD-CHANGE-Q-MGR
                      MOVE 'ALTER QMGR'  TO WS-TEXT
                  WHEN MQCMD-CHANGE-SECURITY
                      MOVE 'ALTER SECURITY'  TO WS-TEXT
                  WHEN MQCMD-CLEAR-Q
                      MOVE 'CLEAR QUEUE'     TO WS-TEXT
                  WHEN MQCMD-CHANGE-STG-CLASS
                      MOVE 'ALTER STGCLASS'  TO WS-TEXT
                  WHEN MQCMD-COPY-STG-CLASS
                      MOVE 'COPY STGCLASS'   TO WS-TEXT
      *
                  WHEN MQCMD-CREATE-AUTH-INFO
                      MOVE 'DEFINE AUTHINFO' TO WS-TEXT
                  WHEN MQCMD-CREATE-BUFFER-POOL
                      MOVE 'DEFINE BUFFPOOL'  TO WS-TEXT
                  WHEN MQCMD-CREATE-CF-STRUC
                      MOVE 'DEFINE CFSTRUCT' TO WS-TEXT
                  WHEN MQCMD-COPY-CF-STRUC
                      MOVE 'COPY CFSTRUCT'   TO WS-TEXT
                  WHEN MQCMD-CREATE-CHANNEL
                      MOVE 'DEFINE  CHANNEL'  TO WS-TEXT
                  WHEN MQCMD-CREATE-NAMELIST
                      MOVE 'DEFINE NAMELIST' TO WS-TEXT
                  WHEN MQCMD-CREATE-PAGE-SET
                      MOVE 'DEFINE PSID'      TO WS-TEXT
                  WHEN MQCMD-CREATE-PROCESS
                      MOVE 'DEFINE PROCESS' TO WS-TEXT
                  WHEN MQCMD-CREATE-Q
                      MOVE 'DEFINE QUEUE'     TO WS-TEXT
                  WHEN MQCMD-CREATE-STG-CLASS
                      MOVE 'DEFINE STGCLASS'  TO WS-TEXT
      *
                  WHEN MQCMD-DELETE-AUTH-INFO
                      MOVE 'DELETE AUTHINFO' TO WS-TEXT
                  WHEN MQCMD-DELETE-BUFFER-POOL
                      MOVE 'DELETE BUFFPOOL'  TO WS-TEXT
                  WHEN MQCMD-DELETE-CF-STRUC
                      MOVE 'DELETE CFSTRUCT' TO WS-TEXT
                  WHEN MQCMD-DELETE-CHANNEL
                      MOVE 'DELETE  CHANNEL'  TO WS-TEXT
                  WHEN MQCMD-DELETE-NAMELIST
                      MOVE 'DELETE NAMELIST' TO WS-TEXT
                  WHEN MQCMD-DELETE-PAGE-SET
                      MOVE 'DELETE PSID'      TO WS-TEXT
                  WHEN MQCMD-DELETE-PROCESS
                      MOVE 'DELETE PROCESS' TO WS-TEXT
                  WHEN MQCMD-DELETE-Q
                      MOVE 'DELETE QUEUE'     TO WS-TEXT
                  WHEN MQCMD-DELETE-STG-CLASS
                      MOVE 'DELETE STGCLASS'  TO WS-TEXT
      *
                  WHEN MQCMD-INQUIRE-AUTH-INFO
                      MOVE 'DISPLAY AUTHINFO' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-ARCHIVE
                      MOVE 'DISPLAY ARCHIVE'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-AUTH-INFO-NAMES
                      MOVE 'DISPLAY AUTHINFO NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CF-STRUC
                      MOVE 'DISPLAY CFSTRUCT'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CF-STRUC-NAMES
                      MOVE 'DISPLAY CFSTRUCT NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-PROCESS-NAMES
                      MOVE 'INQUIRE-PROCESS-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-Q-NAMES
                      MOVE 'INQUIRE-Q-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CHANNEL-NAMES
                      MOVE 'INQUIRE-CHL-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-NAMELIST-NAMES
                      MOVE 'INQUIRE-NL-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-AUTH-INFO-NAMES
                      MOVE 'INQUIRE-AUTHINFO-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-STG-CLASS-NAMES
                      MOVE 'INQUIRE-STGCLASS-NAMES' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CF-STRUC-STATUS
                      MOVE 'DISPLAY CFSTATUS'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-Q-STATUS
                      MOVE 'INQUIRE-Q-STATUS' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CLUSTER-Q-MGR
                      MOVE 'INQUIRE-CLUS-QMGR'   TO WS-TEXT
                  WHEN MQCMD-RESUME-Q-MGR-CLUSTER
                      MOVE 'RESUME-QMGR-CLUSTER' TO WS-TEXT
                  WHEN MQCMD-SUSPEND-Q-MGR-CLUSTER
                      MOVE 'SUSPEND-QMGR-CLUSTER' TO WS-TEXT
                  WHEN MQCMD-REFRESH-CLUSTER
                      MOVE 'REFRESH CLUSTER' TO WS-TEXT
                  WHEN MQCMD-RESET-CLUSTER
                      MOVE 'RESET-CLUSTER'   TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CHANNEL
                      MOVE 'DISPLAY CHANNEL'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CHANNEL-INIT
                      MOVE 'DISPLAY CHANNEL INIT'   TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CHANNEL-STATUS
                      MOVE 'DISPLAY CHS'       TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CMD-SERVER
                      MOVE 'DISPLAY CMDSERV'        TO WS-TEXT
                  WHEN MQCMD-INQUIRE-CONNECTION
                      MOVE 'DISPLAY CONN'  TO WS-TEXT
                  WHEN MQCMD-CHANGE-TRACE
                      MOVE 'ALTER TRACE'     TO WS-TEXT
                  WHEN MQCMD-STOP-Q-MGR
                      MOVE 'STOP QMGR'       TO WS-TEXT
                  WHEN MQCMD-INQUIRE-USAGE
                      MOVE 'INQUIRE-USAGE'   TO WS-TEXT
                  WHEN MQCMD-INQUIRE-PROCESS
                      MOVE 'INQUIRE-PROCESS' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-SECURITY
                      MOVE 'INQUIRE_SECURITY' TO WS-TEXT
                  WHEN MQCMD-INQUIRE-SYSTEM
                      MOVE 'INQUIRE-SYSTEM'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-THREAD
                      MOVE 'INQUIRE THREAD'  TO WS-TEXT
                  WHEN MQCMD-INQUIRE-LOG
                      MOVE 'INQUIRE-LOG'     TO WS-TEXT
                  WHEN MQCMD-INQUIRE-Q
                      MOVE 'INQUIRE-Q'       TO WS-TEXT
                  WHEN MQCMD-INQUIRE-QSG
                      MOVE 'INQUIRE-QSG'     TO WS-TEXT
                  WHEN MQCMD-INQUIRE-Q-MGR
                      MOVE 'INQUIRE-Q-MGR'   TO WS-TEXT
                  WHEN MQCMD-START-CHANNEL-INIT
                      MOVE 'START CHINIT'    TO WS-TEXT
                  WHEN MQCMD-START-CHANNEL-LISTENER
                      MOVE 'START LISTENER'  TO WS-TEXT
                  WHEN MQCMD-START-CHANNEL
                      MOVE 'START CHANNEL'   TO WS-TEXT
                  WHEN MQCMD-STOP-CHANNEL
                      MOVE 'STOP CHANNEL'   TO WS-TEXT
                  WHEN MQCMD-START-TRACE
                      MOVE 'START TRACE'     TO WS-TEXT
                  WHEN MQCMD-INQUIRE-TRACE
                      MOVE 'INQUIRE TRACE'   TO WS-TEXT
                  WHEN MQCMD-COPY-Q
                      MOVE 'COPY Q'          TO WS-TEXT
                  WHEN MQCMD-REFRESH-Q-MGR
                      MOVE 'REFRESH QMGR'    TO WS-TEXT
                  WHEN MQCMD-RESET-Q-STATS
                      MOVE 'RESET-Q-STATS'   TO WS-TEXT
                  WHEN MQCMD-RESOLVE-CHANNEL
                      MOVE 'RESOLVE-CHANNEL' TO WS-TEXT
                  WHEN MQCMD-PING-Q-MGR
                      MOVE 'PING-Q-MGR'      TO WS-TEXT
                  WHEN MQCMD-RESET-Q-MGR
                      MOVE 'RESET QMGR'      TO WS-TEXT
                  WHEN MQCMD-TRACE-ROUTE
                      MOVE 'TRACE ROUTE'     TO WS-TEXT
                  WHEN MQCMD-REFRESH-SECURITY
                      MOVE 'REFRESH SECURITY' TO WS-TEXT
                  WHEN MQCMD-MOVE-Q
                      MOVE 'MOVE-Q'          TO WS-TEXT
                  WHEN MQCMD-RECOVER-BSDS
                      MOVE 'RECOVER BSDS'    TO WS-TEXT
                  WHEN MQCMD-RECOVER-CF-STRUC
                      MOVE 'RECOVER CFSTRUCT' TO WS-TEXT
                  WHEN MQCMD-RESET-TPIPE
                      MOVE 'RESET TPIPE'     TO WS-TEXT
                  WHEN MQCMD-RESOLVE-INDOUBT
                      MOVE 'RESOLVE INDOUBT' TO WS-TEXT
                  WHEN MQCMD-RESUME-Q-MGR
                      MOVE 'RESUME QMGR'     TO WS-TEXT
                  WHEN MQCMD-REVERIFY-SECURITY
                      MOVE 'RVERIFY SECURITY' TO WS-TEXT
                  WHEN MQCMD-SET-ARCHIVE
                      MOVE 'SET ARCHIVE'     TO WS-TEXT
                  WHEN MQCMD-SET-LOG
                      MOVE 'SET LOG'         TO WS-TEXT
                  WHEN MQCMD-SET-SYSTEM
                      MOVE 'SET SYSTEM'      TO WS-TEXT
                  WHEN MQCMD-START-CMD-SERVER
                      MOVE 'START CMDSERV'   TO WS-TEXT
                  WHEN MQCMD-STOP-CMD-SERVER
                      MOVE 'STOP CMDSERV'    TO WS-TEXT
                  WHEN MQCMD-START-Q-MGR
                      MOVE 'START QMGR'      TO WS-TEXT
                  WHEN MQCMD-STOP-CHANNEL-INIT
                      MOVE 'STOP CHINIT'     TO WS-TEXT
                  WHEN MQCMD-STOP-TRACE
                      MOVE 'STOP TRACE'      TO WS-TEXT
                  WHEN MQCMD-SUSPEND-Q-MGR
                      MOVE 'SUSPEND QMGR'    TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-EVENT-ORIGIN
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQEVO-CONSOLE
                      MOVE 'CONSOLE' TO WS-TEXT
                  WHEN MQEVO-INIT
                      MOVE 'INIT' TO WS-TEXT
                  WHEN MQEVO-MSG
                      MOVE 'MSG'       TO WS-TEXT
                  WHEN MQEVO-MQSET
                      MOVE 'MQSET' TO WS-TEXT
                  WHEN MQEVO-INTERNAL
                      MOVE 'INTERNAL'   TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-APPL-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQAT-QMGR
                      MOVE 'QMGR'        TO WS-TEXT
                  WHEN MQAT-CHANNEL-INITIATOR
                      MOVE 'CHINIT'          TO WS-TEXT
                  WHEN MQAT-USER
                      MOVE 'USER'           TO WS-TEXT
                  WHEN MQAT-BATCH
                      MOVE 'BATCH'          TO WS-TEXT
                  WHEN MQAT-RRS-BATCH
                      MOVE 'RRS BATCH'   TO WS-TEXT
                  WHEN MQAT-ZOS 
                      MOVE 'z/OS'        TO WS-TEXT
                  WHEN MQAT-UNIX               
                      MOVE 'UNIX'            TO WS-TEXT
                  WHEN MQAT-WINDOWS
                      MOVE 'WINDOWS'        TO WS-TEXT
                  WHEN MQAT-JAVA 
                      MOVE 'JAVA'           TO WS-TEXT
                  WHEN MQAT-USER       
                      MOVE 'USER'        TO WS-TEXT
                  WHEN MQAT-BROKER
                      MOVE 'BROKER'          TO WS-TEXT
                  WHEN MQAT-IMS-BRIDGE
                      MOVE 'IMS BRIDGE'     TO WS-TEXT
                  WHEN MQAT-USER-LAST 
                      MOVE 'USER LAST'      TO WS-TEXT
                  WHEN MQAT-CICS
                      MOVE 'CICS' TO WS-TEXT
                  WHEN MQAT-IMS
                      MOVE 'IMS' TO WS-TEXT
                  WHEN MQAT-QMGR
                      MOVE 'QMGR' TO WS-TEXT
                  WHEN MQQT-ALIAS
                      MOVE 'MQQT-ALIAS' TO WS-TEXT
                  WHEN MQQT-REMOTE
                      MOVE 'MQQT-REMOTE' TO WS-TEXT
                  WHEN MQRQ-Q-MGR-QUIESCING
                      MOVE 'MQRQ-Q-MGR-QUIESCING' TO WS-TEXT
                  WHEN MQRQ-Q-MGR-STOPPING
                      MOVE 'MQRQ-Q-MGR-STOPPING ' TO WS-TEXT
                  WHEN OTHER
                      MOVE '***OTHER***' TO WS-TEXT
              END-EVALUATE
           END-IF.
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-REASON-QUALIFIER
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQRQ-CHANNEL-STOPPED-OK
                      MOVE 'MQRQ-CHANNEL-OK-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-ERROR
                      MOVE 'MQRQ-CHANNEL-ERROR-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-RETRY
                      MOVE 'MQRQ-CHANNEL-RETRY-STOP' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-DISABLED
                      MOVE 'MQRQ-CHANNEL-DISABLED-STOP' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
           IF MQCFIN-PARAMETER OF MQCFIN = MQIA-Q-TYPE
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQQT-LOCAL
                      MOVE 'LOCAL QUEUE' TO WS-TEXT
                  WHEN MQQT-MODEL
                      MOVE 'MODEL QUEUE' TO WS-TEXT
                  WHEN MQQT-ALIAS
                      MOVE 'ALIAS QUEUE' TO WS-TEXT
                  WHEN MQQT-REMOTE
                      MOVE 'REMOTE QUEUE' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-VALUE OF MQCFIN
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-VALUE           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-VALUE OF MQCFIN
                   ' ' WS-TEXT.
       DISPLAY-INTEGER-STRUC-END.
           EXIT.
      ******************************************************************
      * Process integer START/STOP structure.
      ******************************************************************
       DISPLAY-SSTOP-INT-STRUC SECTION.
      * parameter
           MOVE SPACES TO WS-TEXT-TITLE.
           EVALUATE MQCFIN-PARAMETER OF MQCFIN
               WHEN MQIACF-ERROR-IDENTIFIER
                   MOVE 'MQIACF-ERROR-IDENTIFIER' TO WS-TEXT-TITLE
               WHEN MQIACF-REASON-QUALIFIER
                   MOVE 'MQIACF-REASON-QUALIFIER' TO WS-TEXT-TITLE
               WHEN MQIACF-AUX-ERROR-DATA-INT-1
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-1' TO WS-TEXT-TITLE
               WHEN MQIACF-AUX-ERROR-DATA-INT-2
                   MOVE 'MQIACF-AUX-ERROR-DATA-INT-2' TO WS-TEXT-TITLE
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT-TITLE
           END-EVALUATE.
      *
      * value
           MOVE SPACES TO WS-TEXT.
           IF MQCFIN-PARAMETER OF MQCFIN = MQIACF-REASON-QUALIFIER
              EVALUATE MQCFIN-VALUE OF MQCFIN
                  WHEN MQRQ-CHANNEL-STOPPED-OK
                      MOVE 'MQRQ-CHANNEL-STOPPED-OK' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-ERROR
                      MOVE 'MQRQ-CHANNEL-STOPPED-ERROR' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-RETRY
                      MOVE 'MQRQ-CHANNEL-STOPPED-RETRY' TO WS-TEXT
                  WHEN MQRQ-CHANNEL-STOPPED-DISABLED
                      MOVE 'MQRQ-CHANNEL-STOPPED-DISABLED' TO WS-TEXT
                  WHEN OTHER
                      MOVE '**UNKNOWN**' TO WS-TEXT
              END-EVALUATE
           END-IF.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-VALUE OF MQCFIN
                                WS-LONG-HEXDISP.
      *
           DISPLAY '    ' WS-TEXT-TITLE ' '
                   'X''' WS-LONG-HEXDISP   ''''
      *            ' ' MQCFIN-VALUE OF MQCFIN
                   ' ' WS-TEXT.
      *
       DISPLAY-SSTOP-INT-STRUC-END.
           EXIT.
      ******************************************************************
      * Process integer-list structure.
      ******************************************************************
       DISPLAY-INTEGER-LIST-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL structure'.
      *
           EVALUATE MQCFIL-TYPE OF MQCFIL
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-TYPE OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-TYPE OF MQCFIL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-STRUCLENGTH OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-STRUCLENGTH OF MQCFIL.
      *
      * parameter
           EVALUATE MQCFIL-PARAMETER OF MQCFIL
               WHEN MQIACH-CHANNEL-ERROR-DATA
                   MOVE 'MQIACH-CHANNEL-ERROR-DATA' TO WS-TEXT
               WHEN MQIACH-HDR-COMPRESSION   
                   MOVE 'CHL COMPHDR'               TO WS-TEXT
               WHEN MQIACH-MSG-COMPRESSION      
                   MOVE 'CHL COMPMSG'               TO WS-TEXT
               WHEN OTHER
                   MOVE '*NOT CODED*' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-PARAMETER OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-PARAMETER OF MQCFIL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIL-COUNT OF MQCFIL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIL-COUNT           ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIL-COUNT OF MQCFIL.
      *
           PERFORM TEST BEFORE VARYING L FROM 1 BY 1
             UNTIL (L > MQCFIL-COUNT)
             DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'Value                  =' CFIL-DATA(L)
           END-PERFORM.
       DISPLAY-INTEGER-LIST-STRUC-END.
           EXIT.
      ******************************************************************
      * Process string structure.
      ******************************************************************
       DISPLAY-STRING-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST structure'.
      *
           EVALUATE MQCFST-TYPE OF MQCFST
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-TYPE OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-TYPE OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-STRUCLENGTH OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-STRUCLENGTH OF MQCFST.
      *
      * parameter
           EVALUATE MQCFST-PARAMETER OF MQCFST
               WHEN MQCACF-EVENT-USER-ID
                   MOVE 'MQCACF-EVENT-USER-ID' TO WS-TEXT
               WHEN MQCACF-COMMAND-SCOPE
                   MOVE 'MQCACF-CMDSCOPE'      TO WS-TEXT
               WHEN MQCACF-COMMAND-MQSC
                   MOVE 'MQCACF-COMMAND-MQSC'  TO WS-TEXT
               WHEN MQCACF-FROM-Q-NAME
                   MOVE 'FROM-Q-NAME'          TO WS-TEXT
               WHEN MQCACF-TO-Q-NAME
                   MOVE 'TO-Q-NAME'            TO WS-TEXT
               WHEN MQCACF-EVENT-Q-MGR
                   MOVE 'MQCACF-EVENT-Q-MGR'         TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-IDENTITY
                   MOVE 'MQCACF-EVENT-APPL-ID' TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-NAME
                   MOVE 'MQCACF-EVENT-APPL-NAME'     TO WS-TEXT
               WHEN MQCACF-EVENT-APPL-ORIGIN
                   MOVE 'MQCACF-EVENT-APPL-ORIGIN' TO WS-TEXT
               WHEN MQCACF-APPL-NAME
                   MOVE 'MQCACF-APPL-NAME' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-1
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-1' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-2
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-2' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-3
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-3' TO WS-TEXT
               WHEN MQCA-BASE-Q-NAME
                   MOVE 'MQCA-BASE-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CHANNEL-NAME
                   MOVE 'MQCACH-CHANNEL-NAME' TO WS-TEXT
               WHEN MQCACH-DESC          
                   MOVE 'CHL DESCRIPTION'     TO WS-TEXT
               WHEN MQCACH-MODE-NAME   
                   MOVE 'CHL MODENAME'        TO WS-TEXT
               WHEN MQCACH-USER-ID     
                   MOVE 'CHL USERID'          TO WS-TEXT
               WHEN MQCACH-PASSWORD    
                   MOVE 'CHL PASSWORD'        TO WS-TEXT
               WHEN MQCACH-TP-NAME
                   MOVE 'CHL TP NAME'         TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-NAME
                   MOVE 'CHL SECYEXIT NAME'   TO WS-TEXT
               WHEN MQCACH-MSG-EXIT-NAME
                   MOVE 'CHL MSGEXIT NAME'    TO WS-TEXT
               WHEN MQCACH-SEND-EXIT-NAME
                   MOVE 'CHL SENDEXIT NAME'   TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-NAME
                   MOVE 'CHL RCVEXIT NAME'    TO WS-TEXT
               WHEN MQCACH-MR-EXIT-USER-DATA
                   MOVE 'CHL MREXIT USERDATA' TO WS-TEXT
               WHEN MQCACH-MR-EXIT-NAME
                   MOVE 'CHL MREXIT NAME'    TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-USER-DATA
                   MOVE 'CHL SECYEXIT USERDATA' TO WS-TEXT
               WHEN MQCACH-MSG-EXIT-USER-DATA
                   MOVE 'CHL MSGEXIT USERDATA' TO WS-TEXT
               WHEN MQCACH-SEND-EXIT-USER-DATA
                   MOVE 'CHL SENDEXIT USERDATA' TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-USER-DATA
                   MOVE 'CHL RCVEXIT USERDATA' TO WS-TEXT
               WHEN MQCACH-LOCAL-ADDRESS
                   MOVE 'CHL LOCADDR'         TO WS-TEXT
               WHEN MQCACH-MCA-USER-ID   
                   MOVE 'CHL MCA USERID'      TO WS-TEXT
               WHEN MQCACH-MCA-JOB-NAME 
                   MOVE 'CHL MCA JOBNAME'     TO WS-TEXT
               WHEN MQCACH-MCA-NAME 
                   MOVE 'CHL MCA NAME'     TO WS-TEXT
               WHEN MQCACH-SSL-CIPHER-SPEC
                   MOVE 'CHL SSL CIPHER SPEC' TO WS-TEXT
               WHEN MQCACH-SSL-PEER-NAME
                   MOVE 'CHL SSL PEER NAME'   TO WS-TEXT
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCA-AUTH-INFO-NAME
                   MOVE 'MQCA-AUTHINFO-NAME' TO WS-TEXT
               WHEN MQCA-AUTH-INFO-DESC
                   MOVE 'AUTHINFO-DESC' TO WS-TEXT
               WHEN MQCA-AUTH-INFO-CONN-NAME
                   MOVE 'AUTHINFO-CONN-NAME' TO WS-TEXT
               WHEN MQCA-LDAP-PASSWORD 
                   MOVE 'LDAP PASSWORD'      TO WS-TEXT
               WHEN MQCA-LDAP-USER-NAME
                   MOVE 'LDAP USERNAME'      TO WS-TEXT
               WHEN MQCACF-OBJECT-Q-MGR-NAME
                   MOVE 'MQCACF-OBJECT-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-DESC
                   MOVE 'MQCA-Q-MGR-DESC' TO WS-TEXT
               WHEN MQCA-APPL-ID   
                   MOVE 'MQCA-APPLID'     TO WS-TEXT
               WHEN MQCA-ENV-DATA  
                   MOVE 'MQCA-ENVDATA'    TO WS-TEXT
               WHEN MQCA-NAMELIST-DESC
                   MOVE 'MQCA-NL-DESC'    TO WS-TEXT
               WHEN MQCA-NAMELIST-NAME
                   MOVE 'MQCA-NL-NAME'    TO WS-TEXT
               WHEN MQCA-PROCESS-DESC
                   MOVE 'MQCA-PROCESS-DESC' TO WS-TEXT
               WHEN MQCA-USER-DATA 
                   MOVE 'MQCA-USERDATA'  TO WS-TEXT
               WHEN MQCA-STORAGE-CLASS-DESC
                   MOVE 'MQCA-STGCLASS-DESC' TO WS-TEXT
               WHEN MQCA-XCF-GROUP-NAME
                   MOVE 'MQCA-XCF-GROUP-NAME' TO WS-TEXT
               WHEN MQCA-XCF-MEMBER-NAME
                   MOVE 'MQCA-XCF-MEMBER-NAME' TO WS-TEXT
               WHEN MQCA-PASS-TICKET-APPL
                   MOVE 'MQCA-PASSTKTA'   TO WS-TEXT
               WHEN MQCA-CHANNEL-AUTO-DEF-EXIT
                   MOVE 'MQCA-CHAD-EXIT'  TO WS-TEXT
               WHEN MQCA-CLUSTER-WORKLOAD-DATA
                   MOVE 'MQCA-CLUS-WORKLOAD-DATA' TO WS-TEXT
               WHEN MQCA-CLUSTER-WORKLOAD-EXIT
                   MOVE 'MQCA-CLUS-WORKLOAD-EXIT' TO WS-TEXT
               WHEN MQCA-CLUSTER-NAMELIST    
                   MOVE 'CLUSTER NAMELIST'       TO WS-TEXT
               WHEN MQCA-CLUSTER-NAME        
                   MOVE 'CLUSTER NAME'           TO WS-TEXT
               WHEN MQCA-DEAD-LETTER-Q-NAME
                   MOVE 'MQCA-DLQ-NAME' TO WS-TEXT
               WHEN MQCA-SSL-KEY-REPOSITORY
                   MOVE 'MQCA-SSL-KEY-REPOS' TO WS-TEXT
               WHEN MQCA-SSL-CRL-NAMELIST
                   MOVE 'MQCA-SSL-CRL-NAMELIST' TO WS-TEXT
               WHEN MQCA-IGQ-USER-ID
                   MOVE 'MQCA-IGQ-USERID'    TO WS-TEXT
               WHEN MQCA-DEF-XMIT-Q-NAME
                   MOVE 'MQCA-DEF-XMITQ-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-IDENTIFIER
                   MOVE 'MQCA-QMGR-ID'        TO WS-TEXT
               WHEN MQCA-LU-GROUP-NAME
                   MOVE 'MQCA-LU-GROUP-NAME'  TO WS-TEXT
               WHEN MQCA-LU-NAME
                   MOVE 'MQCA-LU-NAME'        TO WS-TEXT
               WHEN MQCA-LU62-ARM-SUFFIX
                   MOVE 'MQCA-LU62-ARM-SUFFIX' TO WS-TEXT
               WHEN MQCA-DNS-GROUP
                   MOVE 'MQCA-DNS-GROUP'      TO WS-TEXT
               WHEN MQCA-CHINIT-SERVICE-PARM
                   MOVE 'MQCA-CHINIT-SERVICE-PARM' TO WS-TEXT
               WHEN MQCA-ALTERATION-DATE
                   MOVE 'MQCA-ALTERATION-DATE' TO WS-TEXT
               WHEN MQCA-ALTERATION-TIME
                   MOVE 'MQCA-ALTERATION-TIME' TO WS-TEXT
               WHEN MQCA-REPOSITORY-NAMELIST
                   MOVE 'MQCA-REPOSITORY-NAMELIST' TO WS-TEXT
               WHEN MQCA-REPOSITORY-NAME
                   MOVE 'MQCA-REPOSITORY-NAME'     TO WS-TEXT
               WHEN MQCA-QSG-NAME
                   MOVE 'MQCA-QSG-NAME'            TO WS-TEXT
               WHEN MQCA-Q-NAME
                   MOVE 'MQCA-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-MGR-NAME
                   MOVE 'MQCA-REMOTE-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-XMIT-Q-NAME
                   MOVE 'MQCA-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCA-COMMAND-INPUT-Q-NAME
                   MOVE 'COMMAND INPUT Q'  TO WS-TEXT
               WHEN MQCA-TCP-NAME
                   MOVE 'TCP NAME'         TO WS-TEXT
               WHEN MQCA-Q-DESC
                   MOVE 'Q DESCRIPTION'    TO WS-TEXT
               WHEN MQCACH-XMIT-Q-NAME
                   MOVE 'MQCACH-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CONNECTION-NAME
                   MOVE 'MQCACH-CONNECTION-NAME' TO WS-TEXT
               WHEN MQCA-BACKOUT-REQ-Q-NAME
                   MOVE 'BACKOUT QNAME'          TO WS-TEXT
               WHEN MQCA-INITIATION-Q-NAME
                   MOVE 'INITQ NAME'             TO WS-TEXT
               WHEN MQCA-STORAGE-CLASS      
                   MOVE 'STGCLASS'               TO WS-TEXT
               WHEN MQCA-TRIGGER-DATA      
                   MOVE 'TRIGGER DATA'           TO WS-TEXT
               WHEN MQCA-CF-STRUC-NAME
                   MOVE 'CFSTRUCT NAME'          TO WS-TEXT
               WHEN MQCA-CF-STRUC-DESC
                   MOVE 'CFSTRUCT DESC'          TO WS-TEXT
               WHEN MQCA-REMOTE-Q-NAME
                   MOVE 'REMOTE QNAME'           TO WS-TEXT
               WHEN MQCA-CREATION-DATE    
                   MOVE 'CREATION DATE'          TO WS-TEXT
               WHEN MQCA-CREATION-TIME       
                   MOVE 'CREATION TIME'          TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-PARAMETER OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-PARAMETER OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-CODEDCHARSETID OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-CODEDCHARSETID  ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-CODEDCHARSETID OF MQCFST
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFST-STRINGLENGTH OF MQCFST
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFST-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFST-STRINGLENGTH OF MQCFST
                   ' ' WS-TEXT.
      *
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'String=' CFST-DATA(1:MQCFST-STRINGLENGTH) '='.
       DISPLAY-STRING-STRUC-END.
           EXIT.

      ******************************************************************
      * Process byte-string structure.
      ******************************************************************
       DISPLAY-BYTE-STRING-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS structure'.
      *
           EVALUATE MQCFBS-TYPE OF MQCFBS
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-BYTE-STRING
                   MOVE 'BYTE STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-TYPE OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-TYPE OF MQCFBS
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-STRUCLENGTH OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-STRUCLENGTH OF MQCFBS.
      *
      * parameter
           EVALUATE MQCFBS-PARAMETER OF MQCFBS
               WHEN MQBACF-ACCOUNTING-TOKEN
                   MOVE 'MQBACF-ACCOUNTING-TOKEN' TO WS-TEXT
               WHEN MQBACF-CF-LEID
                   MOVE 'MQBACF-CF-LEID'             TO WS-TEXT
               WHEN MQBACF-CONNECTION-ID
                   MOVE 'MQBACF-CONNECTION-ID' TO WS-TEXT
               WHEN MQBACF-CORREL-ID
                   MOVE 'MQBACF-CORREL-ID'           TO WS-TEXT
               WHEN MQBACF-EVENT-ACCOUNTING-TOKEN
                   MOVE 'MQBACF-EVENT-ACCOUNTING-TOKEN' TO WS-TEXT
               WHEN MQBACF-EVENT-SECURITY-ID
                   MOVE 'MQBACF-EVENT-SECURITY-ID' TO WS-TEXT
               WHEN MQBACF-EXTERNAL-UOW-ID
                   MOVE 'MQBACF-EXTERNAL-UOW-ID'      TO WS-TEXT
               WHEN MQBACF-GENERIC-CONNECTION-ID
                   MOVE 'MQBACF-GENERIC-CONNECTION-ID' TO WS-TEXT
               WHEN MQBACF-GROUP-ID
                   MOVE 'MQBACF-GROUP-ID'             TO WS-TEXT
               WHEN MQBACF-MSG-ID
                   MOVE 'MQBACF-MSG-ID'    TO WS-TEXT
               WHEN MQBACF-ORIGIN-UOW-ID
                   MOVE 'MQBACF-ORIGIN-UOW-ID' TO WS-TEXT
               WHEN MQBACF-Q-MGR-UOW-ID
                   MOVE 'MQBACF-Q-MGR-UOW-ID' TO WS-TEXT
               WHEN MQBACF-RESPONSE-ID
                   MOVE 'MQBACF-RESPONSE-ID'       TO WS-TEXT
               WHEN MQBACF-RESPONSE-SET
                   MOVE 'MQBACF-RESPONSE-SET' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-PARAMETER OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-PARAMETER OF MQCFBS
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFBS-STRINGLENGTH OF MQCFBS
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFBS-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFBS-STRINGLENGTH OF MQCFBS
                   ' ' WS-TEXT.
      *
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                'Byte String=' CFBS-DATA(1:MQCFBS-STRINGLENGTH) '='.
       DISPLAY-BYTE-STRING-STRUC-END.
           EXIT.


      ******************************************************************
      * Process GROUP  structure.
      ******************************************************************
       DISPLAY-GROUP-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQGACF structure'.
      *
           EVALUATE MQCFGR-TYPE OF MQCFGR
               WHEN MQCFT-GROUP
                   MOVE 'GROUP'   TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFGR-TYPE OF MQCFGR
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFGR-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFGR-TYPE OF MQCFGR
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFGR-STRUCLENGTH OF MQCFGR
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFGR-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFGR-STRUCLENGTH OF MQCFGR.
      *
      * parameter
           EVALUATE MQCFGR-PARAMETER OF MQCFGR
               WHEN MQGACF-COMMAND-CONTEXT
                   MOVE 'MQGACF-COMMAND-CONTEXT' TO WS-TEXT
               WHEN MQGACF-COMMAND-DATA
                   MOVE 'MQGACF-COMMAND-DATA'         TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFGR-PARAMETER OF MQCFGR
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFGR-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFGR-PARAMETER OF MQCFGR
                   ' ' WS-TEXT.
      * parameter count
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFGR-PARAMETERCOUNT OF MQCFGR
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFGR-PARAMETERCOUNT  ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFGR-PARAMETERCOUNT OF MQCFGR.
      *
           MOVE MQCFGR-STRUC-LENGTH   TO STRUC-LEN.
           MOVE MQCFGR-PARAMETERCOUNT TO G-PARM-COUNT
      * Process each sub-structure in msg
           PERFORM TEST BEFORE VARYING N FROM 1 BY 1
             UNTIL (N > G-PARM-COUNT)
      * Compute index of start of next sub-structure
           COMPUTE FIRST-BYTE = FIRST-BYTE + STRUC-LEN
      * Compute start of length field (offset 4 from start of structure)
           COMPUTE K = FIRST-BYTE + 4
      * Get length of sub-structure
           MOVE W03-MESSAGE-DATA(K:4) TO STRUC-LEN-CHAR
      * Copy sub-structure into work buffer
           MOVE W03-MESSAGE-DATA(FIRST-BYTE:STRUC-LEN) TO WORK-BUF
      * Process sub-structure according to type
           IF MQCFIN-TYPE = MQCFT-INTEGER THEN
              PERFORM DISPLAY-INTEGER-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-INTEGER-LIST THEN
              PERFORM DISPLAY-INTEGER-LIST-STRUC
           ELSE IF MQCFIL-TYPE = MQCFT-STRING-LIST THEN
              PERFORM DISPLAY-STRING-LIST-STRUC
           ELSE IF MQCFST-TYPE = MQCFT-STRING THEN
              PERFORM DISPLAY-STRING-STRUC
           ELSE IF MQCFSL-TYPE = MQCFT-BYTE-STRING THEN
              PERFORM DISPLAY-BYTE-STRING-STRUC
           ELSE
              MOVE 4 TO WS-XTOCHAR-LEN 
              CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFIN-TYPE OF MQCFIN
                                WS-LONG-HEXDISP 
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFIN-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFIN-TYPE OF MQCFIN
                   ' ' WS-TEXT 
              DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                      '** MESSAGE IS NO LONGER IN PCF FORMAT **'
              GO TO DISPLAY-GROUP-STRUC-END
           END-IF END-IF END-IF END-IF END-IF
      * End of loop
           END-PERFORM.
      *
       DISPLAY-GROUP-STRUC-END.
           EXIT.

      ******************************************************************
      * Process START/STOP string structure.
      ******************************************************************
       DISPLAY-SSTOP-STRING-STRUC SECTION.
      * parameter
           EVALUATE MQCFST-PARAMETER OF MQCFST
               WHEN MQCACF-APPL-NAME
                   MOVE 'MQCACF-APPL-NAME' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-1
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-1' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-2
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-2' TO WS-TEXT
               WHEN MQCACF-AUX-ERROR-DATA-STR-3
                   MOVE 'MQCACF-AUX-ERROR-DATA-STR-3' TO WS-TEXT
               WHEN MQCA-BASE-Q-NAME
                   MOVE 'MQCA-BASE-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CHANNEL-NAME
                   MOVE 'MQCACH-CHANNEL-NAME' TO WS-TEXT
               WHEN MQCA-PROCESS-NAME
                   MOVE 'MQCA-PROCESS-NAME' TO WS-TEXT
               WHEN MQCA-NAMELIST-NAME
                   MOVE 'MQCA-NL-NAME' TO WS-TEXT
               WHEN MQCACF-OBJECT-Q-MGR-NAME
                   MOVE 'MQCACF-OBJECT-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-MGR-NAME
                   MOVE 'MQCA-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-Q-NAME
                   MOVE 'MQCA-Q-NAME' TO WS-TEXT
               WHEN MQCA-REMOTE-Q-MGR-NAME
                   MOVE 'MQCA-REMOTE-Q-MGR-NAME' TO WS-TEXT
               WHEN MQCA-XMIT-Q-NAME
                   MOVE 'MQCA-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-XMIT-Q-NAME
                   MOVE 'MQCACH-XMIT-Q-NAME' TO WS-TEXT
               WHEN MQCACH-CONNECTION-NAME
                   MOVE 'MQCACH-CONNECTION-NAME' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
      *
           DISPLAY  '    ' WS-TEXT
                   ' =' CFST-DATA(1:MQCFST-STRINGLENGTH) '='.
      *
       DISPLAY-SSTOP-STRING-STRUC-END.
           EXIT.
      ******************************************************************
      * Process string-list structure.
      ******************************************************************
       DISPLAY-STRING-LIST-STRUC SECTION.
           DISPLAY ' '
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL structure'.
      *
           EVALUATE MQCFSL-TYPE OF MQCFSL
               WHEN MQCFT-COMMAND
                   MOVE 'COMMAND' TO WS-TEXT
               WHEN MQCFT-RESPONSE
                   MOVE 'RESPONSE' TO WS-TEXT
               WHEN MQCFT-INTEGER
                   MOVE 'INTEGER' TO WS-TEXT
               WHEN MQCFT-STRING
                   MOVE 'STRING' TO WS-TEXT
               WHEN MQCFT-INTEGER-LIST
                   MOVE 'INTEGER LIST' TO WS-TEXT
               WHEN MQCFT-STRING-LIST
                   MOVE 'STRING-LIST' TO WS-TEXT
               WHEN MQCFT-EVENT
                   MOVE 'EVENT' TO WS-TEXT
               WHEN OTHER
                   MOVE '**UNKNOWN**' TO WS-TEXT
           END-EVALUATE.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-TYPE OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-TYPE            ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-TYPE OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-STRUCLENGTH OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-STRUCLENGTH     ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-STRUCLENGTH OF MQCFSL.
      *
      * parameter
           EVALUATE MQCFSL-PARAMETER OF MQCFSL
               WHEN MQCACH-SEND-EXIT-USER-DATA
                   MOVE 'CHL SENDEXIT USERDATA'     TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-USER-DATA
                   MOVE 'CHL RCVEXIT USERDATA'      TO WS-TEXT
               WHEN MQCACH-MSG-EXIT-USER-DATA
                   MOVE 'CHL MSGEXIT USERDATA'      TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-USER-DATA   
                   MOVE 'CHL SECYEXIT USERDATA'     TO WS-TEXT
               WHEN MQCACH-SEND-EXIT-NAME        
                   MOVE 'CHL SENDEXIT NAME'         TO WS-TEXT
               WHEN MQCACH-RCV-EXIT-NAME     
                   MOVE 'CHL RCVEXIT NAME'          TO WS-TEXT
               WHEN MQCACH-MSG-EXIT-NAME       
                   MOVE 'CHL MSGEXIT NAME'          TO WS-TEXT
               WHEN MQCACH-SEC-EXIT-NAME        
                   MOVE 'CHL SECYEXIT NAME'         TO WS-TEXT
               WHEN OTHER
                   MOVE '*NOT CODED*' TO WS-TEXT
            END-EVALUATE 
 
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-PARAMETER OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-PARAMETER       ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-PARAMETER OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-CODEDCHARSETID OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-CODEDCHARSETID  ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-CODEDCHARSETID OF MQCFSL
                   ' ' WS-TEXT.
      *
           MOVE SPACES TO WS-TEXT.
           MOVE 4 TO WS-XTOCHAR-LEN.
           CALL 'XTOCHAR' USING WS-XTOCHAR-LEN
                                MQCFSL-STRINGLENGTH OF MQCFSL
                                WS-LONG-HEXDISP.
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'MQCFSL-STRINGLENGTH    ='
                   'X''' WS-LONG-HEXDISP   ''''
                   ' ' MQCFSL-STRINGLENGTH OF MQCFSL
                   ' ' WS-TEXT.
      *
           DISPLAY WS-TIME-DISPLAY ' ' WS-BLANK9
                   'Str length = ' MQCFSL-STRINGLENGTH.
           PERFORM TEST BEFORE VARYING L FROM 1 BY 1
             UNTIL (L > MQCFSL-COUNT)
             COMPUTE K = (L - 1) * MQCFSL-STRINGLENGTH + 1
             DISPLAY 'String=' CFSL-DATA(K:MQCFSL-STRINGLENGTH) '='
           END-PERFORM.
       DISPLAY-STRING-LIST-STRUC-END.
           EXIT.
      *
       ACCEPT-TIME SECTION.
           ACCEPT WS-TIME FROM TIME.
           MOVE WS-TIME-HOUR TO WS-TIME-DISPLAY-HOUR.
           MOVE WS-TIME-MIN  TO WS-TIME-DISPLAY-MIN.
           MOVE WS-TIME-SEC  TO WS-TIME-DISPLAY-SEC.
           MOVE WS-TIME-HUND TO WS-TIME-DISPLAY-HUND.
       ACCEPT-TIME-END.
           EXIT.
      *
      * ---------------------------------------------------------------
      *                  End of program
      * ---------------------------------------------------------------
